/******************************************************************************
 *
 * File: Starter.cpp
 *
 *****************************************************************************/

#include <PalmOS.h>
#include <PCENativeCall.h>
#include "ljp_pnoload.h"
#include "StarterRsc.h"
#include <MemGlue.h>

/***********************************************************************
 *
 *	Internal Constants
 *
 ***********************************************************************/
#define appFileCreator			'PDac'	// register your own at http://www.palmos.com/dev/creatorid/
#define appVersionNum			0x01
#define appPrefID				0x00
#define appPrefVersionNum		0x01

// Define the minimum OS version we support (5.0 for now).
#define kOurMinVersion	sysMakeROMVersion(5,0,0,sysROMStageDevelopment,0)
#define kPalmOS10Version	sysMakeROMVersion(1,0,0,sysROMStageRelease,0)

enum {
  hf_pin_present = 1              // has VG
  // 2, 4, 8, 16 ...
};

static UInt32 hw_flags = 0;

#define EndianSwap32(n)	(((((UInt32) n) << 24) & 0xFF000000) |	\
                         ((((UInt32) n) <<  8) & 0x00FF0000) |	\
                         ((((UInt32) n) >>  8) & 0x0000FF00) |	\
                         ((((UInt32) n) >> 24) & 0x000000FF))

#define ALIGN4(addr) (((UInt32)(addr) + 3) & 0xFFFFFFFC)

#define DEBUGS(x)
typedef struct PnoEntryHeader {
	UInt32 r10Value;
	UInt32 pnoMainAddress;
	UInt32 userDataP;
} PnoEntryHeader;

// this is the startup code defined in CW's ARMlet_Startup.c with a table of
// offsets into the PNO following the startup code

typedef struct PnoHeaderType {
	UInt32 startupCode[8];	// changes based on the instruction count in startup code 
	UInt32 pnoMain;         // offset to ARMletMain routine
	UInt32 signature;       // special PNO signature value
	UInt32 dataStart;       // offset to start of initialized data
	UInt32 roDataStart;     // offset to start of read-only initialized data
	UInt32 bssStart;        // offset to start of uninitialized data
	UInt32 bssEnd;          // offset to end of uninitialized data
	UInt32 codeRelocsStart; // offset to start of data-to-code relocation list
	UInt32 codeRelocsEnd;   // offset to end of data-to-code relocation list
	UInt32 dataRelocsStart; // offset to start of data-to-data relocation list
	UInt32 dataRelocsEnd;   // offset to end of data-to-data relocation list
	UInt32 altEntryCode[8];	// changes based on the instruction count in alternate entry code 
} PnoHeaderType;

UInt32 wholesize = 0;

/***********************************************************************
 *
 *	Internal Functions
 *
 ***********************************************************************/


/***********************************************************************
 *
 * FUNCTION:    RomVersionCompatible
 *
 * DESCRIPTION: This routine checks that a ROM version is meet your
 *              minimum requirement.
 *
 * PARAMETERS:  requiredVersion - minimum rom version required
 *                                (see sysFtrNumROMVersion in SystemMgr.h 
 *                                for format)
 *              launchFlags     - flags that indicate if the application 
 *                                UI is initialized.
 *
 * RETURNED:    error code or zero if rom is compatible
 *
 * REVISION HISTORY:
 *
 *
 ***********************************************************************/
MemPtr GetThePNO();
MemPtr GetThePNO()
{

	UInt32 numRes = 1;
	MemHandle mh;
	MemPtr wholeP;
	UInt32 offset = 0;
	MemPtr mpP;
	UInt8 *tempP;

	while(mh = DmGetResource('ARMC', numRes++))
	{
		wholesize+=MemHandleSize(mh);
		DmReleaseResource(mh);
	}
	if (numRes == 0)
		return NULL;

	wholeP = MemGluePtrNew(wholesize);
	if (!wholeP)
		return NULL;

	numRes = 1;

	tempP = wholeP;

	while (mh = DmGetResource('ARMC', numRes++))
	{
		mpP = MemHandleLock(mh);
		//DmWrite(wholeP, offset, mpP, MemPtrSize(mpP));
		MemMove(tempP,mpP,MemPtrSize(mpP));
		tempP = tempP + MemPtrSize(mpP);
		MemPtrUnlock(mpP);
		DmReleaseResource(mh);
	}

	return wholeP;

}


#define memNewChunkFlagNonMovable    0x0200
#define memNewChunkFlagAllowLarge    0x1000  // this is not in the sdk *g*

SysAppInfoPtr 
SysGetAppInfo(SysAppInfoPtr *uiAppPP, SysAppInfoPtr *actionCodeAppPP)
  SYS_TRAP(sysTrapSysGetAppInfo); 

/*UInt32 host_event_handler ( UInt32 arg ) {
  UInt32 a;

	a=arg;

    // memglueptrnew

    //return (UInt32) MemPtrNew ( a );
    return (UInt32) MemChunkNew ( 0,a,0x200|0x1000 );

}*/

UInt32 host_event_handler ( UInt32 size );
UInt32 host_event_handler ( UInt32 size ) {
  SysAppInfoPtr appInfoP;
  UInt16        ownerID;


  //ownerID =((SysAppInfoPtr)SysGetAppInfo(&appInfoP, &appInfoP))->memOwnerID;

 // return (UInt32)MemChunkNew ( 0, size, ownerID | memNewChunkFlagNonMovable | memNewChunkFlagAllowLarge );

	return (UInt32)MemGluePtrNew(size);
}

static void hw_set_fullscreen ( UInt8 fullscreenp ) 
{
	EventType event;

  if ( fullscreenp ) {

    if ( hw_flags & hf_pin_present ) 
    {
        PINSetInputAreaState ( pinInputAreaClosed );
      	StatHide();
	    EvtGetEvent(&event,0);
	    while(event.eType != nilEvent)
	    {
	    	EvtGetEvent(&event,0);
	    	SysHandleEvent(&event);
	    }

    }

  } else {

    if ( hw_flags & hf_pin_present ) {
      StatShow();
    }

  }

  return;
}

void hw_guess_screen_dimensions ( /*UInt32 *r_width, UInt32 *r_height,
				   UInt32 *r_pitch*/ )
{
  /* WAIT; OS5 has WinScreenGetAttribute; life is good. */
  /* Process:
   * OS < 5
   *   ZOT requires OS5.
   *   Sony?
   *     If Sony, check Sony API .. its either low res, or we can ask API
   *   Non-Sony
   *     Is it a T|W? It should have DIA..
   *     If DIA, ask it.
   *     Otherwise, low res, bail.
   * OS >= 5
   *   DIA?
   *     If so, ask it.
   *   No DIA, so.. Sony?
   *     If Sony, ask it.
   *   No DIA, No Sony...
   *     Is it Treo? IF slo, low res
   *     If not Treo, must be high res (T|T1, T|T2)
   * Now, if new low res OS5 device comes out.. sucks.
   */
  UInt32 pitch = 0;
  UInt32 width = 0;
  UInt32 height = 0;
	UInt32 deviceID;
	//char Temp1[30],Temp2[30],Temp3[30]; 

	Err devErr; 



  // is it double density or single density? this is only available in
  // Window Manager v4; OS5 includes v4 always, however.
  WinScreenGetAttribute ( winScreenRowBytes, &pitch );
  //   T|T3 returned 640b for pitch; 16bit -> 320px
  //   zodiac returns 960b; 16bit -> 480px
  WinScreenGetAttribute ( winScreenWidth, &width );
  WinScreenGetAttribute ( winScreenHeight, &height );
  // zodiac lies returns 320 width always
  
  /*StrCopy(Temp1,StrIToA(Temp1,pitch));
  StrCat(Temp1,"-");
  StrCopy(Temp2,StrIToA(Temp2,width));
  StrCat(Temp2,"-");
  StrCopy(Temp3,StrIToA(Temp3,height));


  FrmCustomAlert(10024,Temp1,Temp2,Temp3);*/

  // deal with lies by using pitch..
  width = pitch / 2;
  pitch = pitch / 2;

  // Do we see a DIA present? (T|T3, Zodiac, UX50, Garmin, later devices..)
  {
    UInt32 version;
    Err err = FtrGet ( pinCreator, pinFtrAPIVersion, &version );
    if ( ! err && version ) {
      //PINS exists
      //DEBUGS("PIN present");
      hw_flags |= hf_pin_present;
      hw_set_fullscreen(1);

    } // pin?
  } // DIA PIN?

  // done
  //*r_width = width;
  //*r_height = height;
  //*r_pitch = pitch;
  
  devErr = FtrGet(sysFtrCreator, sysFtrNumOEMDeviceID, &deviceID); 
	if (deviceID == 'prmr')
	{
		width = 480;
		height = 320;
		pitch = 480;
	}


	FtrSet('PDac',1113,(unsigned long)width);
	FtrSet('PDac',1114,(unsigned long)height);
	FtrSet('PDac',1115,(unsigned long)pitch);


  return;
}


static Err RomVersionCompatible(UInt32 requiredVersion, UInt16 launchFlags)
{
	UInt32 romVersion;
	UInt32 displayFtrP;
	
#ifndef DEV_BUILD
	//SysSetOrientation(sysOrientationLandscape);
	//PINSetInputAreaState(1);
	//StatHide();
	displayFtrP =(UInt32)BmpGetBits(WinGetBitmap(WinGetDisplayWindow()));
	FtrSet('PDac',1111,(unsigned long)displayFtrP);
#endif
	FtrSet('PDac',1112,(unsigned long)host_event_handler);

	hw_guess_screen_dimensions();
	// See if we're on in minimum required version of the ROM or later.
	FtrGet(sysFtrCreator, sysFtrNumROMVersion, &romVersion);
	if (romVersion < requiredVersion)
		{
		if ((launchFlags & (sysAppLaunchFlagNewGlobals | sysAppLaunchFlagUIApp)) ==
			(sysAppLaunchFlagNewGlobals | sysAppLaunchFlagUIApp))
			{
			FrmAlert (RomIncompatibleAlert);
		
			// Palm OS 1.0 will continuously relaunch this app unless we switch to 
			// another safe one.
			if (romVersion <= kPalmOS10Version)
				{
				AppLaunchWithCommand(sysFileCDefaultApp, sysAppLaunchCmdNormalLaunch, NULL);
				}
			}
		
		return sysErrRomIncompatible;
		}

	return errNone;
}


/***********************************************************************
 *
 * FUNCTION:    GetObjectPtr
 *
 * DESCRIPTION: This routine returns a pointer to an object in the current
 *              form.
 *
 * PARAMETERS:  formId - id of the form to display
 *
 * RETURNED:    void *
 *
 * REVISION HISTORY:
 *
 *
 ***********************************************************************/
static void * GetObjectPtr(UInt16 objectID)
{
	FormPtr frmP;

	frmP = FrmGetActiveForm();
	return FrmGetObjectPtr(frmP, FrmGetObjectIndex(frmP, objectID));
}

/***********************************************************************
 *
 * FUNCTION:     AppStart
 *
 * DESCRIPTION:  Get the current application's preferences.
 *
 * PARAMETERS:   nothing
 *
 * RETURNED:     Err value 0 if nothing went wrong
 *
 * REVISION HISTORY:
 *
 *
 ***********************************************************************/
static Err AppStart(void)
{
	return errNone;
}


/***********************************************************************
 *
 * FUNCTION:    AppStop
 *
 * DESCRIPTION: Save the current state of the application.
 *
 * PARAMETERS:  nothing
 *
 * RETURNED:    nothing
 *
 * REVISION HISTORY:
 *
 *
 ***********************************************************************/
static void AppStop(void)
{
	// Close all the open forms.
	FrmCloseAllForms ();
}


#define FLUSH_D_CACHE {int i,j;UInt8 *tmpPtr;\
		tmpPtr=MemPtrNew(32768);j=0;\
		for (i=0;i<32768;i++) j+=(int)tmpPtr[i];\
		MemPtrFree(tmpPtr);tmpPtr=MemPtrNew(32768);\
		j=0;for (i=0;i<32768;i++) j+=(int)tmpPtr[i];\
		MemPtrFree(tmpPtr);\
	}
/***********************************************************************
 *
 * FUNCTION:    StarterPalmMain
 *
 * DESCRIPTION: This is the main entry point for the application.
 *
 * PARAMETERS:  cmd - word value specifying the launch code. 
 *              cmdPB - pointer to a structure that is associated with the launch code. 
 *              launchFlags -  word value providing extra information about the launch.
 *
 * RETURNED:    Result of launch
 *
 * REVISION HISTORY:
 *
 *
 ***********************************************************************/
static UInt32 StarterPalmMain(UInt16 cmd, MemPtr /*cmdPBP*/, UInt16 launchFlags)
{
	Err error;
    UInt32 new_depth = 16;
    FormPtr frmP;
	UInt32 processor;
	UInt32 result;

	switch (cmd)
		{
		case sysAppLaunchCmdNormalLaunch:
			//error = AppStart();
	WinScreenMode(winScreenModeSet,NULL,NULL,&new_depth,NULL);


	error = RomVersionCompatible (kOurMinVersion, launchFlags);
	if (error) return (error);

			// call the PACE Native Object
			FtrGet(sysFtrCreator, sysFtrNumProcessorID, &processor);

			if (sysFtrNumProcessorIsARM(processor))
			{
				PnoDescriptor pno;
				Err err;
				MemPtr pnoPtr = GetThePNO();

				//err = PnoLoadFromResources(&pno, 'ARMC', 1, 'PDac', 1);
				
				if (!pnoPtr)
					SysFatalAlert("failed to load pno");

				ljp_PnoLoad(&pno, pnoPtr,wholesize);
				FtrPtrFree('PDac',1);
				
				
				//FLUSH_D_CACHE
				
				result = ljp_PnoCall(&pno, 0);
				ljp_PnoUnload(&pno);
			}

			//if (error) 
			//	return error;
				
			//FrmGotoForm(MainForm);
			//AppEventLoop();
			//AppStop();
			break;

		default:
			break;

		}
	
	return errNone;
}


/***********************************************************************
 *
 * FUNCTION:    PilotMain
 *
 * DESCRIPTION: This is the main entry point for the application.
 *
 * PARAMETERS:  cmd - word value specifying the launch code. 
 *              cmdPB - pointer to a structure that is associated with the launch code. 
 *              launchFlags -  word value providing extra information about the launch.
 * RETURNED:    Result of launch
 *
 * REVISION HISTORY:
 *
 *
 ***********************************************************************/
UInt32 PilotMain( UInt16 cmd, MemPtr cmdPBP, UInt16 launchFlags)
{
	return StarterPalmMain(cmd, cmdPBP, launchFlags);
}

