
#include <PalmOS.h>

#ifdef __cplusplus
extern "C" {
#endif

//#include "host.h"
//#include "utils.h"

//#include "twlib.h"
#include "stdfile.h"
//#include "PalmMameLoader.h"


static char chdir [ 128 ] = ""; // add to VFSPATH for path
 static UInt16 voliter = 0xFFEE;

int fchdir ( char *path ) {
  StrCopy ( chdir, path );
  return ( 0 );
}

UInt16 palm_vfs_vol ( void ) {
  UInt16 volref = 0;
  UInt32 voliter2 = vfsIteratorStart;
  FileRef file;
  UInt16 firstvolref;

  // can we enumerate at all?
  if ( VFSVolumeEnumerate ( &volref,  &voliter2 ) != errNone ) {
    return ( 0 );
  }

  // store first succeeding volume
  firstvolref = volref;

  // can we open our directory? If so, we found our directory :)
  if ( VFSFileOpen ( volref, VFSPATH2, vfsModeRead, &file ) == errNone ) {
    VFSFileClose ( file );
    return ( volref );
  }

  // look through other volumes, trying to find our directory
  while ( VFSVolumeEnumerate ( &volref,  &voliter2 ) == errNone ) {

    if ( VFSFileOpen ( volref, VFSPATH2, vfsModeRead, &file ) == errNone ) {
      VFSFileClose ( file );
      return ( volref );
    }

  }

  //return ( voliter );
  return ( firstvolref );
}

FILE *fopen ( const char *filename, char *mode ) {
//FILE *fopen ( char *filename, char *mode ) {
  char path [ 256 ];
  Err error;
  FILE *myfile = (FILE *)MemPtrNew ( sizeof(FILE) );
  UInt16 vfsmode = 0;

  if ( voliter == 0xFFEE ) {
    voliter = palm_vfs_vol();
  }



  StrCopy ( myfile -> filename, filename );
  myfile -> tail = 0;
  myfile -> ref = 0;
  myfile -> size = 0;

  if ( StrChr ( mode, 'r' ) && StrChr ( mode, 'w' ) ) {
    myfile -> bufferp = 0; // no buffering on read+write files
    //DEBUGS("Internal eror: Game fopen() is confusing");
    vfsmode = vfsModeReadWrite;
  } else if ( StrChr ( mode, 'w' ) ) {
    myfile -> bufferp = 2; // buffering single direction stream
    vfsmode = vfsModeWrite;
  } else {
    myfile -> bufferp = 1; // buffering single direction stream
    vfsmode = vfsModeRead;
  }

  // looks like general purpose work, so don't screw with path
  path [ 0 ] = '\0';
  StrCat ( path, VFSPATH );
  StrCat ( path, chdir );
  StrCat ( path, filename );
  //StrPrintF ( path, "%s%s", VFSPATH, filename );

  //debugs(path);

  error = VFSFileOpen ( voliter, path, vfsmode /*vfsModeReadWrite*/,
			& (myfile->ref) );

#ifdef SF_LITTLEENDIAN
  myfile -> ref = ByteSwap32 ( myfile -> ref );
#endif

  if ( error != errNone ) {

    if ( StrChr ( mode, 'w' ) ) {
      /* couldn't open it, but try and create it.. */
      error = VFSFileCreate ( voliter, path );

      if ( error != errNone ) {
	//DEBUGS ( "create: Failed" );
	return ( NULL );
      }

      error = VFSFileOpen ( voliter, path, vfsmode/*vfsModeReadWrite*/,
			    & (myfile->ref) );

#ifdef SF_LITTLEENDIAN
      myfile -> ref = ByteSwap32 ( myfile -> ref );
#endif

      if ( error != errNone ) {
	//DEBUGS ( "open write: Failed" );
	MemPtrFree ( myfile );
	return ( NULL );
      }

    } else {
      //DEBUGS ( "open: Failed" );
      MemPtrFree ( myfile );
      return ( NULL );
    }

  }

  VFSFileSize ( myfile -> ref, & (myfile -> size) );

#ifdef SF_LITTLEENDIAN
  //myfile -> size = ByteSwap32 ( myfile -> size );
#endif


  return ( myfile );
}

Int8 fclose ( FILE *file ) {


  if ( file -> bufferp == 2 && file -> tail ) {
    // write buffer, so we need to empty the buffer into the stream
    UInt32 result;
    VFSFileWrite ( file -> ref, file -> tail, file -> buffer, &result );
  }

  VFSFileClose ( file -> ref );

  MemPtrFree ( file );


  return ( 0 );
}

UInt32 zfwrite ( const void *_buf, UInt32 size, UInt32 num, FILE *file ) {
//UInt32 fwrite ( char *buf, UInt32 size, UInt32 num, FILE *file ) {
  char *buf = (char*) _buf;
  UInt32 result;


  // for fwrite, lets assume they're calling it since they want to write
  // a block of stuff, not just a single character; so first lets flush
  // any buffer so far, and then write out their buffer
  // (later could shove their buf into our file buffer..)
#if 0
  Err error;

  if ( file -> tail ) {
    VFSFileWrite ( file -> ref, file -> tail, file -> buffer, &result );
    file -> tail = 0;
  }

  if ( size*num ) {
    error = VFSFileWrite ( file -> ref, size*num, buf, &result );
  }
#else
  result = size*num;
  while ( result ) {
    fputc ( *buf++, file );
    result--;
  }
#endif


  //return ( result );
  return ( num );
}

int fputc ( UInt8 c, FILE *file ) {


  if ( file == stdout ) {
    //screen_push ( c );
  } else {

    //draw_progress_bar ( 100 * file -> tail / 255 );

    // buffer large enough to hold another char?
    if ( file -> tail == TAILMAX ) {
      UInt32 result;
      VFSFileWrite ( file -> ref, file -> tail, file -> buffer, &result );
      file -> tail = 0;
      //fwrite ( &c, 1, 1, file );
    }

    // insert into buffer
    file -> buffer [ file -> tail++ ] = c;

  }


  return ( c );
}

UInt8 file_exists ( char *filename ) {
  FILE *f = fopen ( filename, "r" );

  if ( f ) {
    fclose ( f );
    return ( 1 );
  }

  return ( 0 );
}

UInt32 fread ( void *_buf, UInt32 size, UInt32 num, FILE *file ) {
//UInt32 fread ( char *buf, UInt32 size, UInt32 num, FILE *file ) {
  char *buf = (char*)_buf;
  UInt32 result;
  Err error;
  UInt32 ext = size * num;


  // do we have any data in the buffer already? if so, lets first use
  // that and then pick up any extra needed
  if ( ext < file -> tail ) {
    // buffer already has all the data
    //DEBUGS("less");

    //DEBUGS ("fread using mem buffer; tested?" );
    //while(1);

    // pick up buffered bytes
    MemMove ( buf, file -> buffer, ext );

    // shuffle buffer up into place
    MemMove ( file -> buffer, file -> buffer + ext, file -> tail - ext );

    // update tail to new size
    file -> tail -= ext;

  } else {
    // buffer doesn't have enough data
    //DEBUGS("more");

    // move buffer into buf
    MemMove ( buf, file -> buffer, file -> tail ); // might be zero

    // go to end of buff
    buf += file -> tail;

    // num remaining
    ext -= file -> tail;

    // empty buffer
    file -> tail = 0; // now empty

    // pick up remaining
    error = VFSFileRead ( file -> ref, ext, buf, &result );
    if (result == 0)
    	return 0;

  }


  return ( result );
  //return ( num );
}

UInt32 ftell ( FILE *file ) {
  UInt32 result;
  Err error;


  error = VFSFileTell ( file -> ref, &result );

  if ( file -> bufferp == 1 ) {
    result -= file -> tail;
  } else if ( file -> bufferp == 2 ) {
    result += file -> tail;
  }


  return ( result );
}

int fgetc ( FILE *file ) {
  UInt8 c;


  // buffer empty? If so, populate it..
  if ( file -> tail == 0 ) {
    //fread ( &c, 1, 1, file );
    UInt32 size = 255;

    if ( file -> size - ftell ( file ) < 255 ) {
      size = file -> size - ftell ( file );
    }

    fread ( file -> buffer, size, 1, file );

    file -> tail += size;
  }

  // already in the buffer?
  if ( file -> tail ) {

    // disrupts loading display
    //draw_progress_bar ( 100 * file -> tail / 255 );

    c = file -> buffer [ 0 ];
    MemMove ( file -> buffer, file -> buffer + 1, file -> tail - 1 );
    file -> tail -= 1;

  }


  return ( c ); // -1 on error?
}

char * fgets(char * s, int n, FILE * file)
{
	char *	p = s;
	int			c;
	
	if (--n < 0)
		return(NULL);
	
	if (n)
		do
		{
			c = fgetc(file);
			
			if (c == EOF)
				if (p != s)
					break;
				else
				{
					return(NULL);
				}
			
			*p++ = c;
		}
		while (c != '\n' && --n);
	
	*p = 0;
	
	return(s);
}

int fseek ( FILE *file, UInt32 rel, UInt16 source ) {
  Err error;


  if ( source == SEEK_SET ) {
    source = vfsOriginBeginning;
  } else if ( source == SEEK_CUR ) {
    source = vfsOriginCurrent;
  } else if ( source == SEEK_END ) {
    source = vfsOriginEnd;
  } else {
    source = vfsOriginBeginning;
  }

  file -> tail = 0; // should only fseeking on a read stream so we can dump it
  error = VFSFileSeek ( file -> ref, source, rel );


  return ( 0 ); // success
}


void CreateDirectory ( const char *filename ) {
 //*static UInt32 voliter = 0xFFEE;
  char path [ 256 ];
  Err error;
  UInt32 vfsmode = 0;

  if ( voliter == 0xFFEE ) {
    voliter = palm_vfs_vol();
  }

  // looks like general purpose work, so don't screw with path
  path [ 0 ] = '\0';
  StrCat ( path, VFSPATH );
  StrCat ( path, chdir );
  StrCat ( path, filename );
  //StrPrintF ( path, "%s%s", VFSPATH, filename );

  //DEBUGS(path);

  error = VFSDirCreate ( voliter, path );
}

UInt32 file_size(const char *filename)
{
  Err error;
  FileRef dummy;
  UInt32 fsize;
  unsigned char fname[256]="";
  char *f;
  
  if ( voliter == 0xFFEE ) {
    voliter = palm_vfs_vol();
  }
  
	//SafeStrCopy(fname,PALMVFSDIR,256,__FILE__,__LINE__);
	//SafeStrCat(fname,filename,256,__FILE__,__LINE__);
	if (filename[1] == ':') //Absolute path
	{
		f=(char *)filename;
		f+=3;
		
	}
	else //relative - add prefix
	{
		SafeStrCopy(fname,VFSPATH,256,__FILE__,__LINE__);
		SafeStrCat(fname,filename,256,__FILE__,__LINE__);
		f=(char *)fname;
	}
	
  error = VFSFileOpen ( voliter, f, vfsModeRead ,&dummy );
  
  if (!error)
  	error = VFSFileSize(dummy,&fsize);
  	if (!error)
  	{
  		VFSFileClose(dummy);
  		return fsize;
  	}
  
  return 0;

}

int GetDir( char *filename )
{
	UInt32 it;
	int count=0;
	FileInfoType fileinf;
	FileRef dir;
	char buf[256];
	char path[256];
	char *p;

	
	if ( voliter == 0xFFEE ) 
	{
    	voliter = palm_vfs_vol();
    }

	fileinf.nameBufLen = 72;
	fileinf.nameP = buf;
	StrCopy ( path, VFSPATH );
  	StrCat ( path, chdir );
  	StrCat ( path, filename );
	VFSFileOpen (voliter, path, vfsModeRead, &dir);
	it = vfsIteratorStart;
	while (it != vfsIteratorStop) 
	{
	  if (VFSDirEntryEnumerate (dir, &it, &fileinf))
	    break;
	  //FrmCustomAlert( resAlertEntry, "Entry", buf, " ");
	  p=FileList;
	  p=p+count*15;
	  StrNCopy(p,buf,14);
	  p+=14;
	  *p=0;
  	  ++count;

	}
	VFSFileClose (dir);

	return count;

}

int GetDirCount( char *filename )
{
	UInt32 it;
	int count=0;
	FileInfoType fileinf;
	FileRef dir;
	char buf[256];
	char path[256];

	
	if ( voliter == 0xFFEE ) 
	{
    	voliter = palm_vfs_vol();
    }

	fileinf.nameBufLen = 72;
	fileinf.nameP = buf;
	StrCopy ( path, VFSPATH );
  	StrCat ( path, chdir );
  	StrCat ( path, filename );
	VFSFileOpen (voliter, path, vfsModeRead, &dir);
	it = vfsIteratorStart;
	while (it != vfsIteratorStop) 
	{
	  if (VFSDirEntryEnumerate (dir, &it, &fileinf))
	    break;
	  ++count;

	}
	VFSFileClose (dir);

	return count;

}

Err ImportVFS_To_SD(UInt16 *cardNoP,LocalID *dbIDP, char *name)
{
	Err error;
	char pathname[256];
	
	StrCopy(pathname,VFSPATH2);
 	StrCat ( pathname, chdir );
	StrCat(pathname,name);
	
  if ( voliter == 0xFFEE ) {
    voliter = palm_vfs_vol();
  }

	error= VFSImportDatabaseFromFile (voliter,pathname,cardNoP,dbIDP);
	
	return error;
}


#ifdef __cplusplus
} // extern "C"
#endif
