/***************************************************************************

    M.A.M.E.CE3  -  Multiple Arcade Machine Emulator for Pocket PC
    Win32 Portions Copyright (C) 1997-98 Michael Soderstrom and Chris Kirmse
    
    This file is part of MAMECE3, and may only be used, modified and
    distributed under the terms of the MAME license, in "MAME.txt".
    By continuing to use, modify or distribute this file you indicate
    that you have read the license and understand and accept it fully.

 ***************************************************************************/

/***************************************************************************

  GDIDisplay.c

 ***************************************************************************/
#include <TapWave.h>
#include <PalmOS.h>
#include "Playgame.h"
#include "GDIDisplay.h"
#include "driver.h"
#include "dirty.h"
#include "HostPalm.h"
#include "filters.h"
//#include "uclock.h"
#include "StarterRsc.h"
#include "ZSound.h"
#include "utils.h"


/***************************************************************************
    function prototypes
 ***************************************************************************/

int				GDI_init(options_type *options);
void			GDI_exit(void);
//BOOL			GDI_OnMessage(HWND hWnd, UINT Msg, WPARAM wParam, LPARAM lParam, LRESULT* pResult);

static void			DrawToScreen(void);
static void 		DrawToScreenScale(void);

static void			SetPen(int pen, unsigned char red, unsigned char green, unsigned char blue);
static void			SetPaletteColors(void);
static void			AdjustPalette(void);
static int			GetBlackPen(void);
void			AdjustColorMap(void);
void			Display_MapColor(unsigned char* pRed, unsigned char* pGreen, unsigned char* pBlue);
static void			Throttle(void);

static void			update_display(void);

void			Display_WriteBitmap(struct osd_bitmap* tBitmap, PALETTEENTRY* pPalEntries);
static void DrawToScreen16(void);
static void DrawToScreen16Scale(void);

static void DrawToScreen16Direct(void);
static void DrawToScreen16DirectScale(void);
static void DrawToScreen8BitIndex(void);
static void DrawIcons(void);
static void DrawIcons8(void);
static void ConvertIcons16to8();
static void DrawBatteryIcon8();
static void DrawBatteryIcon();
static void ZDrawToScreen16Direct(void);
static void ZDrawToScreen(void);
static void ZDrawToScreen16(void);

static UInt8 *Global_screen;
static int Global_adj_width;
static RectangleType MameScreen;

/***************************************************************************
    External variables
 ***************************************************************************/

struct OSDDisplay   GDIDisplay = 
{
    { GDI_init },               /* init              */
    { GDI_exit },               /* exit              */
	//{ GDI_OnMessage },		/* OnMessage		 */
};

/***************************************************************************
    Internal structures
 ***************************************************************************/

#define MAKECOL(r, g, b) (((r) & 0x001F) << 10 | ((g) & 0x001F) << 5 | ((b) & 0x001F))

/***********************************************************************/

/*
 * Macro to construct a frame buffer compatible rgb565 color given
 * three 8 bit components. This is a manually optimized version that
 * is consistent with the other color macros here.
 *
 * Note that the 68k version of this macro generates data that is
 * byte-swapped into little-endian format. This means that data passed
 * to TwGfxDrawBitmap and TwGfxWriteSurface will be properly arranged
 * if you use this macro.
 */
#define MakeDisplayRGB_BigEndian(_r,_g,_b) \
  ( (((_g) & 0xFC) << 11) | (((_b) & 0xF8) << 5) | ((_r) & 0xF8) | (((_g) & 0xFF) >> 5) )

#define MakeDisplayRGB_LittleEndian(_r,_g,_b) \
  ( (((_r) & 0xF8) << 8) | (((_g) & 0xFC) << 3) | (((_b) & 0xF8) >> 3) )

#if CPU_TYPE == CPU_68K
#define MakeDisplayRGB(_r,_g,_b) MakeDisplayRGB_BigEndian(_r,_g,_b)
#else
#define MakeDisplayRGB(_r,_g,_b) MakeDisplayRGB_LittleEndian(_r,_g,_b)
#endif


#define PF_15BIT			0		/* 16 x555 Format */
#define PF_16BIT			1		/* 16 565 Format */
#define PF_24BITRGB			2		/* 24 RGB Format */
#define PF_32BITRGB			3		/* 32 XRGB Format */

//#define OSD_NUMPENS			(256)
#define FRAMESKIP_LEVELS	12
#define MAX_FRAMESKIP		8
#define FRAMES_TO_SKIP		20	/* skip the first few frames from the FPS calculation */
								/* to avoid counting the copyright and info screens */


//struct GDIBitmap
//{
//	int linesize;
//	int bufsize;
//	HBITMAP bitmap;
//	BITMAPINFO bi;
	// Don't add anything after BITMAPINFO.. as the RGBQUAD colors must follow directly after it!!
//};

struct tDisplay_private
{
    struct osd_bitmap*  m_pMAMEBitmap;
    //struct osd_bitmap*  m_pUpdateBitmap;

	//TwGfxSurfaceType				*m_hBitmap;
	//TwGfxSurfaceType				*m_hOldBitmap;
	//HDC					m_hMemDC;

	UInt8**				m_pScreenLines;

    RECT                m_ClientRect;
    RECT                m_DrawRect;

	BOOL				m_bStretch;
	BOOL                m_bScanlines;
    BOOL                m_bDouble;
	BOOL                m_bUseDirty;
	int					m_nScreenWidth;
	int					m_nScreenHeight;
	int					m_nScreenDepth;
	int                 m_nDepth;
	int					m_PixelFormat;


    BOOL                m_bUpdatePalette;
    //HPALETTE            m_hPalette;
    UInt8        *m_PalEntries;
    //PALETTEENTRY        m_AdjustedPalette[OSD_NUMPENS];
	UInt16				*m_Pal16;

    UInt16                m_nUIPen;


	//from display
   /* Gamma/Brightness */
    //unsigned char   m_pColorMap[OSD_NUMPENS];
    //double          m_dGamma;
    //int             m_nBrightness;

	/* Frames per second (FPS) info */
	BOOL            m_bShowFPS;
	int             m_nShowFPSTemp;

    /* Speed throttling / frame skipping */
	BOOL            m_bThrottled;
	BOOL            m_bAutoFrameskip;
	int             m_nFrameSkip;
	int             m_nFrameskipCounter;
    int             m_nFrameskipAdjust;
    int             m_nSpeed;
	UInt32        m_PrevFrames[FRAMESKIP_LEVELS];
	UInt32        m_Prev;

    /* vector game stats */
	int             m_nVecUPS;
	int             m_nVecFrameCount;

    /* average frame rate data */
	int             frames_displayed;
	UInt32        start_time;
	UInt32        end_time;  /* to calculate fps average on exit */
 
    /* AVI Capture params */
//    BOOL                m_bAviCapture;      /* Capture AVI mode */
//    BOOL                m_bAviRun;          /* Capturing frames */
//    int                 m_nAviShowMessage;  /* Show status if !0 */
	
	/* Device-Manufacturer ID */
	int m_nDevID;
};


/***************************************************************************
    Internal variables
 ***************************************************************************/

static struct tDisplay_private      This;

static int	m_bpp;
// moved these 4 variable to global in order to improve draw_to_screen - 11-30-01  Techmaster
static int  m_pitchX;
static int  m_pitchY;
static int	iheight;
static int	iwidth;
static int	BaseWidthOffset;
static int	iAdjustBase = 0;
static int  iAdjustHeight = 0;
static UInt32 destwidth;
static UInt32 destheight;
static int modifiable_palette;
static int screen_colors;
static int iminx,imaxx,iminy,imaxy;
static UInt8 batteryPercent = 100;
static UInt8 BatteryIcon = 3;
static int i8bitMode = 0;
static void    (*drawtoscreen) (void);
static void    (*drawicons) (void);
static void    (*drawbattery) (void);
static TwGfxPointType destpoint;
static TwGfxBitmapType aBitmap;
static TwGfxRectType srcRect;
static TwGfxRectType destRect;

/***************************************************************************
    External OSD functions  
 ***************************************************************************/

//
//  put here anything you need to do when the program is started. Return 0 if 
//  initialization was successful, nonzero otherwise.
//
int GDI_init(options_type *options)
{
	int i;
	
	This.m_pMAMEBitmap      = NULL;
	//This.m_pUpdateBitmap    = NULL;

	This.m_pScreenLines		= NULL;
	
	This.m_bStretch         = FALSE; // options->stretch
    This.m_bScanlines       = FALSE; // options->hscan_lines; // Scanlines don't work.
    This.m_bDouble          =  1;// (options->scale == 2);

    This.m_bUseDirty        = options->use_dirty;
	This.m_nScreenDepth		= 16;//16;options->screendepth;	 // Added to correct colors - Techmaster
	This.m_nDepth           = 16;		 // Added to correct colors - Techmaster
	This.m_nUIPen           = 0;

	//This.m_dGamma            = max(0, options->gamma);
    //This.m_nBrightness       = max(0, options->brightness);

	This.m_bShowFPS          = options->showfps;
	This.m_nShowFPSTemp      = 0;
 
	This.m_bThrottled        = TRUE; //TRUE; //Techmaster
    This.m_bAutoFrameskip    = TRUE;
	This.m_nFrameSkip        = 0;
	This.m_nFrameskipCounter = 0;
	This.m_nFrameskipAdjust  = 0;
	This.m_nSpeed            = 0;
	This.m_Prev              = TimGetTicks();
    
	This.m_nVecUPS           = 0;
    This.m_nVecFrameCount    = 0;
 
	This.frames_displayed    = 0;
    This.start_time          = TimGetTicks();
    This.end_time            = TimGetTicks();
	This.m_nDevID			 = options->DevID;

    for (i = 0; i < FRAMESKIP_LEVELS; i++)
        This.m_PrevFrames[i] = This.m_Prev;

    if (This.m_bAutoFrameskip)
        This.m_nFrameSkip = 0;


	// Initialize map. //
    //AdjustColorMap();

    This.m_bUpdatePalette   = FALSE;
    //This.m_hPalette         = NULL;
    //memset(This.m_PalEntries,      0, OSD_NUMPENS * sizeof(PALETTEENTRY));
    //memset(This.m_AdjustedPalette, 0, OSD_NUMPENS * sizeof(PALETTEENTRY));
	//memset(This.m_Pal16,		   0, OSD_NUMPENS * sizeof(UInt16));
     	
    
    // Check for inconsistent parameters. //
    if (This.m_bScanlines == TRUE
    &&  This.m_bDouble    == FALSE)
    {
        This.m_bScanlines = FALSE;
    }

    if (This.m_nDepth < 8)
        This.m_nDepth = 8;
    else
    if (8 < This.m_nDepth)
        This.m_nDepth = 16;

    return 0;
}


//
//  put here cleanup routines to be executed when the program is terminated.
//
void GDI_exit(void)
{
	free(This.m_PalEntries);
	free(This.m_Pal16);
}



//
//  Create a bitmap. Also, call osd_clearbitmap() to appropriately initialize it to 
//  the background color.
//
struct osd_bitmap* GD_new_bitmap(int width, int height,int depth, int IsDisplay)
{
       struct osd_bitmap*  pBitmap;
       int twdepth;
		//TwGfxSurfaceInfoType surfInfo;
		Err error;

    if (Machine->orientation & ORIENTATION_SWAP_XY)
    {
        int     temp;

        temp   = width;
        width  = height;
        height = temp;
    }

    pBitmap = (struct osd_bitmap*)malloc(sizeof(struct osd_bitmap));

    if (pBitmap != NULL)
    {
        unsigned char *  bm;
		//TwGfxSurfaceType *bmsurface;
        int     i;
        int     safety;
        int     rdwidth;

		pBitmap->width  = width;
        pBitmap->height = height;
        pBitmap->depth  = depth;

        if (pBitmap->width > 64)
			safety = 8;
        else
           safety = 0;

        rdwidth = (width + 7) & ~7;     /* round width to a quadword */
        
        if (depth == 8)
        	twdepth = 5;
        else if (depth == 16)
        	twdepth = 1;
        else
        	twdepth = 1;

		bm = NULL;
		
		if (IsDisplay && !IsZodiac)
		{
			if (depth == 8 && ((Machine->drv->video_attributes & VIDEO_MODIFIES_PALETTE) == 0) && !ZScreenStretch)
			{
				Err error;
				WinScreenMode(winScreenModeSet,NULL,NULL,&screenDepth,NULL);
				oldDrawWinH = WinGetDrawWindow();
				offScreenH = WinCreateOffscreenWindow((rdwidth + (2 * safety)),(height + (2 * safety)), nativeFormat, &error);
				WinSetDrawWindow(oldDrawWinH);
				bm = BmpGetBits(WinGetBitmap(offScreenH));
				screenBufferP = BmpGetBits(WinGetDrawWindow());
				i8bitMode = 1;
			}
			else
        		bm = (unsigned char*)malloc((rdwidth + 2 * safety) * (height + 2 * safety) * depth / 8);
        	
        }
        else
        {
        	bm = (unsigned char*)malloc((rdwidth + 2 * safety) * (height + 2 * safety) * depth / 8);
        }
		if (bm == NULL)
        {
            free(pBitmap);
            return NULL;
        }

        if ((pBitmap->line = malloc(height * sizeof(unsigned char *))) == 0)
        {
        	if (IsDisplay)
        	{
            	free(bm);
            }
            else
            {
            	free(bm);
            }
            
            free(pBitmap);
            return 0;
        }

        for (i = 0; i < height; i++)
            pBitmap->line[i] = &bm[(i + safety) * (rdwidth + 2 * safety) * depth / 8 + safety];

        pBitmap->_private = bm;

        GD_clearbitmap(pBitmap);
    }

    return pBitmap;
}


//
//   Free memory allocated in create_bitmap.
//
void GD_free_bitmap(struct osd_bitmap* pBitmap, int IsDisplay)
{
	if (IsDisplay && (i8bitMode))
	{
		if (pBitmap != NULL)
	    {
	        free(pBitmap->line);
	        //free(pBitmap->_private);
	        WinDeleteWindow(offScreenH, false);
	        free(pBitmap);
	    }
	}
	else
	{
		if (pBitmap != NULL)
	    {
	        free(pBitmap->line);
	        free(pBitmap->_private);
	        free(pBitmap);
	    }
	}
}


//
//  Create a display screen, or window, large enough to accomodate a bitmap
//  of the given dimensions.
//  Return a osd_bitmap pointer or 0 in case of error.
//
struct osd_bitmap* GD_create_display(int width, int height,int depth, int attributes)
{
    unsigned int    i;
    RECT            Rect;
	UInt32			pal[255];		// Extra space for LOGPALETTE.. must follow LogPalette
    char			TitleBuf[256];
	int				screen_modulo;
	int temp;
	char temps[20];
	int mwidth,mheight;

    // Find out if display depth is 15 bpp or greater. //
    This.m_nScreenDepth = 16;

	This.m_PixelFormat = PF_16BIT;

	// Set up direct access array //
	This.m_nScreenWidth  = screenWidth;
	This.m_nScreenHeight = screenHeight;

	This.m_nDepth = depth;


    if (This.m_bUseDirty)
    {
        if (Machine->orientation & ORIENTATION_SWAP_XY)
            InitDirty(height, width, USE_DIRTYRECT);
        else
            InitDirty(width, height, USE_DIRTYRECT);
    }

    // osd_create_bitmap will swap width and height if neccesary. //
    This.m_pMAMEBitmap = GD_new_bitmap(width, height, depth, 1);

	mwidth = Machine->drv->screen_width;
	mheight = Machine->drv->screen_height;

	if(Machine->drv->video_attributes == VIDEO_TYPE_VECTOR)
	{
		iwidth = Machine->drv->screen_width;
		iheight = Machine->drv->screen_height;
		iminx = 0;
		imaxx = Machine->drv->screen_width;
		iminy = 0;
		imaxy = Machine->drv->screen_height;

	
	}
	else
	{
		iwidth = Machine->drv->visible_area.max_x - Machine->drv->visible_area.min_x + 1;
		iheight = Machine->drv->visible_area.max_y - Machine->drv->visible_area.min_y + 1;
		iminx = Machine->drv->visible_area.min_x;
		imaxx = Machine->drv->visible_area.max_x;
		iminy = Machine->drv->visible_area.min_y;
		imaxy = Machine->drv->visible_area.max_y;
	}
	
	//AK Memory Protection -- don't overwrite past screen boundary!
	/*if (imaxx > screenWidth)
		imaxx = screenWidth;
	if (imaxy > screenHeight)
		imaxy = screenHeight;*/
	
	
	
	if (Machine->orientation & ORIENTATION_SWAP_XY)
	{
		temp=iminx; iminx=iminy; iminy=temp;
		temp=imaxx; imaxx=imaxy; imaxy=temp;
		temp=iwidth;
		iwidth = iheight;
		iheight = temp;
		temp = mwidth;
		mwidth = mheight;
		mheight = temp;
		
	}

	
	if (Machine->orientation & ORIENTATION_FLIP_X)
	{
		iminx = mwidth-imaxx-1;
		if (iminx < 0)
			iminx = 0;
	}
	if (Machine->orientation & ORIENTATION_FLIP_Y)
	{
		iminy = mheight-imaxy-1;
		if (iminy <0 )
			iminy = 0;
	}
		set_ui_visarea(iminx + 10, iminy, (iminx + iwidth) - 10, (iminy + iheight) - 1);

	/*StrIToA(temps,iwidth);
	FrmCustomAlert(10024,"iwidth",temps,"");
	StrIToA(temps,iheight);
	FrmCustomAlert(10024,"iheight",temps,"");
	*/
	if (!IsZodiac)
	{

		if (!ZScreenStretch)
		{
			if (iheight > (screenHeight-menuHeight))
				iheight = (screenHeight-menuHeight);
			if (iwidth > (screenWidth-menuWidth))
				iwidth = (screenWidth-menuWidth);
		}


		if ((imaxx-iminx) > (screenWidth-menuWidth))
		{
			iAdjustBase = 0;
			BaseWidthOffset = 0;
		}
		else
		{	
			iAdjustBase = (((screenWidth-menuWidth)-(imaxx-iminx))  / 2);
			BaseWidthOffset = (imaxx-iminx) - iwidth;
		}

		if ((imaxy-iminy) > (screenHeight-menuHeight))
		{
			iAdjustHeight = 0;
		}
		else
		{	
			iAdjustHeight = (((screenHeight-menuHeight)-(imaxy-iminy))  / 2);
		}
	
	
		if ((double)iwidth/screenWidth < (double)iheight/screenHeight)
		{
			destwidth = (screenHeight-menuWidth)*iwidth/iheight;
			destheight = (screenHeight-menuHeight);
		}
		else
		{
			destheight = iheight*(screenWidth-menuHeight)/iwidth;
			destwidth = (screenWidth-menuWidth);
		}
		if (ZScreenStretch)
			iAdjustBase = (((screenWidth-menuWidth)-destwidth)  / 2);
		
		if (iAdjustBase < 0)
			iAdjustBase = 0;

		if (!ZScreenStretch)
		{
			Global_screen = screenBufferP;
			Global_adj_width = screenWidth;
		}
		else
		{
			Global_screen = screenBufferScaleP;
			Global_adj_width = OFFSCREEN_BUFFER_WIDTH;
		}

		RctSetRectangle(&MameScreen,iminx, iminy, iwidth, iheight);
		RctOffsetRectangle(&MameScreen, 8, 8);//AK for safety bits around image
		if (i8bitMode)
		{
			WinHandle tempwin;
			UInt8 *tempb;
			Err error;
			RectangleType tempRect;
			
			RctSetRectangle(&tempRect,0,0,screenWidth,1);
			
			tempwin = WinCreateOffscreenWindow(screenWidth,1, nativeFormat, &error);
			tempb = BmpGetBits(WinGetBitmap(tempwin));
			
			MemSet(tempb,screenWidth,0);
			for (int l=0;l<screenHeight;l++)
				WinCopyRectangle(tempwin,oldDrawWinH,&tempRect,0,l,winPaint);

			
		}
	}
	else
	{
		
		if (iheight > OFFSCREEN_BUFFER_HEIGHT)
			iheight = OFFSCREEN_BUFFER_HEIGHT;
		if (iwidth > OFFSCREEN_BUFFER_WIDTH)
			iwidth = OFFSCREEN_BUFFER_WIDTH;
		

		TwGfxMakeRect(srcRect,0,0,iwidth,iheight);
		
		if ((double)iwidth/(480) < (double)iheight/(320))
		{
			destwidth = ((320-menuWidth)*iwidth/iheight);
			TwGfxMakeRect(destRect,((((480-menuWidth)-(double)destwidth)/2)+0.5),0,destwidth,320-menuHeight);
		}
		else
		{
			destheight = (iheight*(480-menuHeight)/iwidth);
			TwGfxMakeRect(destRect,0,(((320-menuHeight)-(double)destheight)/2),480-menuWidth,destheight);
		}
		iAdjustBase = (((480-menuWidth)-destwidth)  / 2);

		TwGfxRectType aRect = {0,0,480,320};
		twGlue->TwGfxFillRect_(displaySurface, &aRect, TwGfxComponentsToPackedRGB(0,0,0));
	}

	return This.m_pMAMEBitmap;
}



//
//  Set the actual display screen but don't allocate the screen bitmap.
//
int GD_set_display(int width, int height, int attributes)
{
    //SetForegroundWindow(MAMECE3App.m_hWnd);
    return 0; 
}

//
//   Shut down the display
//
void GD_close_display(void)
{
	ExitDirty();
    
    GD_free_bitmap(This.m_pMAMEBitmap, 1);
	//osd_free_bitmap(This.m_pUpdateBitmap);
	free(This.m_pScreenLines);

	This.m_pMAMEBitmap = NULL;
	This.m_pScreenLines = NULL;
}


//
//  palette is an array of 'totalcolors' R,G,B triplets. The function returns
//  in *pens the pen values corresponding to the requested colors.
//  If 'totalcolors' is 32768, 'palette' is ignored and the *pens array is filled
//  with pen values corresponding to a 5-5-5 15-bit palette
int GD_allocate_colors(unsigned int totalcolors, const unsigned char *palette, unsigned short *pens, int modifiable)
{
    unsigned int i;
	modifiable_palette = modifiable;
	screen_colors = totalcolors;
	
	if (This.m_nDepth != 8)
		screen_colors += 2;
	else 
		screen_colors = 256;
	
	This.m_PalEntries = malloc(3 * screen_colors * sizeof(unsigned char));
	This.m_Pal16 = malloc(screen_colors * sizeof(UInt16));
	if (This.m_PalEntries == 0 || This.m_Pal16 == 0)
		return 1;

	for (i = 0;i < screen_colors;i++)
		This.m_PalEntries[3*i+0] = This.m_PalEntries[3*i+1] = This.m_PalEntries[3*i+2] = 0;
	
    if (This.m_nDepth != 8 && modifiable == 0)
    {
		int r,g,b;

		for (i = 0;i < totalcolors;i++)
		{
			r=palette[3*i+0];
			g=palette[3*i+1];
			b=palette[3*i+2];

			*pens++ = MakeDisplayRGB(r,g,b);
			SetPen(i, r,  g, b);
		}

		Machine->uifont->colortable[0] = MakeDisplayRGB(0x00,0x00,0x00);
		Machine->uifont->colortable[1] = MakeDisplayRGB(0xff,0xff,0xff);
		Machine->uifont->colortable[2] = MakeDisplayRGB(0xff,0xff,0xff);
		Machine->uifont->colortable[3] = MakeDisplayRGB(0x00,0x00,0x00);
		
		if (IsZodiac)
			drawtoscreen = &ZDrawToScreen16Direct;
		else if (ZScreenStretch)
			drawtoscreen = &DrawToScreen16DirectScale;
		else
			drawtoscreen = &DrawToScreen16Direct;
		
		drawicons = &DrawIcons;
		drawbattery = &DrawBatteryIcon;

	}
	else
	{
		if (This.m_nDepth == 8 && totalcolors >= 255)
		{
			int bestblack,bestwhite;
			int bestblackscore,bestwhitescore;


			bestblack = bestwhite = 0;
			bestblackscore = 3*255*255;
			bestwhitescore = 0;
			for (i = 0;i < totalcolors;i++)
			{
				int r,g,b,score;

				r = palette[3*i+0];
				g = palette[3*i+1];
				b = palette[3*i+2];
				score = r*r + g*g + b*b;

				if (score < bestblackscore)
				{
					bestblack = i;
					bestblackscore = score;
				}
				if (score > bestwhitescore)
				{
					bestwhite = i;
					bestwhitescore = score;
				}
			}

			for (i = 0;i < totalcolors;i++)
				pens[i] = i;

			/* map black to pen 0, otherwise the screen border will not be black */
			pens[bestblack] = 0;
			pens[0] = bestblack;

			Machine->uifont->colortable[0] = pens[bestblack];
			Machine->uifont->colortable[1] = pens[bestwhite];
			Machine->uifont->colortable[2] = pens[bestwhite];
			Machine->uifont->colortable[3] = pens[bestblack];
		}
		else
		{
			/* reserve color 1 for the user interface text */
			This.m_PalEntries[3*1+0] = This.m_PalEntries[3*1+1] = This.m_PalEntries[3*1+2] = 0xff;
			SetPen(0,0,0,0);
			SetPen(1,0xFF,0xFF, 0xFF);			
			Machine->uifont->colortable[0] = 0;
			Machine->uifont->colortable[1] = 1;
			Machine->uifont->colortable[2] = 1;
			Machine->uifont->colortable[3] = 0;

			/* fill the palette starting from the end, so we mess up badly written */
			/* drivers which don't go through Machine->pens[] */
			for (i = 0;i < totalcolors;i++)
				pens[i] = (screen_colors-1)-i;
		}

		for (i = 0;i < totalcolors;i++)
		{
			This.m_PalEntries[3*pens[i]+0] = palette[3*i];
			This.m_PalEntries[3*pens[i]+1] = palette[3*i+1];
			This.m_PalEntries[3*pens[i]+2] = palette[3*i+2];
			
			SetPen(pens[i], palette[3*i],  palette[3*i+1], palette[3*i+2]);

		}
		
		//AK choose drawing functions
		//much of the ifs are redundant but it makes it easy to add or remove
		//functions for testing certain video modes.
		if (IsZodiac)
		{
			if (This.m_nDepth == 8)
				drawtoscreen = &ZDrawToScreen;
			else
				drawtoscreen = &ZDrawToScreen16;
				
			drawicons = &DrawIcons;
			drawbattery = &DrawBatteryIcon;
              	
		}
		else
		{
		
			if (This.m_nDepth == 8)
				if (modifiable == 0 && !ZScreenStretch)
				{
					drawtoscreen = &DrawToScreen8BitIndex;
					drawicons = &DrawIcons8;
					drawbattery = &DrawBatteryIcon8;
					i8bitMode = 1;
					if (MenuOption)
						ConvertIcons16to8();

				}
				else
					if (ZScreenStretch)
					{
						drawtoscreen = &DrawToScreenScale;
						drawicons = &DrawIcons;
						drawbattery = &DrawBatteryIcon;
					}
					else
					{
						drawtoscreen = &DrawToScreen;
						drawicons = &DrawIcons;
						drawbattery = &DrawBatteryIcon;
					}
			else//16-bit mode
				if (ZScreenStretch)
				{
					drawtoscreen = &DrawToScreen16Scale;
					drawicons = &DrawIcons;
					drawbattery = &DrawBatteryIcon;
				}
				else
				{
					drawtoscreen = &DrawToScreen16;
					drawicons = &DrawIcons;
					drawbattery = &DrawBatteryIcon;
				}
		}
	}
    
	return 0;
}


//
//  Change the color of the pen.
//
void GD_modify_pen(int pen, unsigned char red, unsigned char green, unsigned char blue)
{
//   assert(This.m_nDepth == 8); // Shouldn't modify pen in 16 bit color depth game mode! //

//   assert(0 <= pen && pen < OSD_NUMPENS);

	if (	This.m_PalEntries[3*pen+0] != red ||
			This.m_PalEntries[3*pen+1] != green ||
			This.m_PalEntries[3*pen+2] != blue)
	{
		This.m_PalEntries[3*pen+0] = red;
		This.m_PalEntries[3*pen+1] = green;
		This.m_PalEntries[3*pen+2] = blue;

	    SetPen(pen, red, green, blue);

	    //This.m_bUpdatePalette = TRUE;
	}
}


//
//  Get the color of a pen.
//
void GD_get_pen(int pen, unsigned char* pRed, unsigned char* pGreen, unsigned char* pBlue)
{

	if (This.m_nDepth != 8 && modifiable_palette == 0)
	{
        /**pRed   = (pen >> twGfxRShift) & twGfxRMask;
        *pGreen = (pen >> twGfxGShift) & twGfxGMask;
        *pBlue  = (pen << twGfxBShift) & twGfxBMask;*/
        *pRed   = pen & twGfxRMask;
        *pGreen = pen & twGfxGMask;
        *pBlue  = pen & twGfxBMask;
	}
	else
	{
		*pRed =   This.m_PalEntries[3*pen+0];
		*pGreen = This.m_PalEntries[3*pen+1];
		*pBlue =  This.m_PalEntries[3*pen+2];
	}
}

/*
    Update the display.
*/
static int volup, voldown, volmute, incfs, decfs, showfps;
static int oldvol;

void GD_update_display(void)
{
	Int16 pScreenX = 0;
	Int16 pScreenY = 0;
	Boolean pPenDown = false;
	//EvtFlushPenQueue();
	EvtGetPenNative (WinGetDrawWindow(),&pScreenX, &pScreenY, &pPenDown);  //Slows down Zodiac until screen tap???

    int need_to_clear_bitmap = 0;

    if (GD_skip_this_frame() == 0)
    {   
        if (This.m_nShowFPSTemp)
        {
            This.m_nShowFPSTemp--;
            if ((This.m_bShowFPS == FALSE)
            &&  (This.m_nShowFPSTemp == 0))
            {
                need_to_clear_bitmap = 1;
            }
        }
        if (input_ui_pressed(IPT_UI_SHOW_FPS) || (MenuOption > 0 && pPenDown && RctPtInRectangle(pScreenX,pScreenY,&StatusBar.RectStat[12]) && !showfps))
		{
			if (This.m_bShowFPS)
			{
				This.m_bShowFPS = 0;
				need_to_clear_bitmap = 1;
			}
			else
			{
				This.m_bShowFPS ^= 1;
				if (This.m_bShowFPS == 0)
				{
					need_to_clear_bitmap = 1;
				}
			}
			showfps = 1;
		}
        /* Wait until it's time to update the screen. */
        Throttle();
      
		update_display();

//        if (need_to_clear_bitmap)
//            GD_clearbitmap(Machine->scrbitmap);

		SwitchDirty();

        if (need_to_clear_bitmap)
           GD_clearbitmap(Machine->scrbitmap);

        if (This.m_bThrottled
        &&  This.m_bAutoFrameskip
        &&  This.m_nFrameskipCounter == 0)
        {
            if (This.m_nSpeed < 60)
            {
                This.m_nFrameskipAdjust = 0;
                This.m_nFrameSkip += 3;
                if (This.m_nFrameSkip > MAX_FRAMESKIP)
                    This.m_nFrameSkip = MAX_FRAMESKIP;
            }
            else
            if (This.m_nSpeed < 80)
            {
                This.m_nFrameskipAdjust = 0;
                This.m_nFrameSkip += 2;
                if (This.m_nFrameSkip >= MAX_FRAMESKIP)
                    This.m_nFrameSkip = MAX_FRAMESKIP;
            }
            else
            if (This.m_nSpeed < 99) /* allow 99% speed */
            {
                This.m_nFrameskipAdjust = 0;
                /* don't push frameskip too far if we are close to 100% speed */
                if (This.m_nFrameSkip < 8)
                    This.m_nFrameSkip++;
            }
            else
            if (100 <= This.m_nSpeed)
            {
                /* increase frameskip quickly, decrease it slowly */
                This.m_nFrameskipAdjust++;
                if (This.m_nFrameskipAdjust >= 3)
                {
                    This.m_nFrameskipAdjust = 0;
                    if (This.m_nFrameSkip > 0)
                        This.m_nFrameSkip--;
                }
            }
		}
    }
	
    /*
        Adjust frameskip.
    */
    if (input_ui_pressed(IPT_UI_FRAMESKIP_INC) || (MenuOption > 0 && pPenDown && RctPtInRectangle(pScreenX,pScreenY,&StatusBar.RectStat[6]) && !incfs))
    {
        if (This.m_bAutoFrameskip)
        {
            This.m_bAutoFrameskip = FALSE;
            This.m_nFrameSkip     = 0;
        }
        else
        {
            if (This.m_nFrameSkip == FRAMESKIP_LEVELS - 1)
            {
                This.m_nFrameSkip     = 0;
                This.m_bAutoFrameskip = TRUE;
            }
            else
                This.m_nFrameSkip++;
        }

        if (This.m_bShowFPS == FALSE)
            This.m_nShowFPSTemp = 2 * Machine->drv->frames_per_second;

        /* reset the frame counter every time the frameskip key is pressed, so */
        /* we'll measure the average FPS on a consistent status. */
        This.frames_displayed = 0;
        incfs = 1;
    }

    if (input_ui_pressed(IPT_UI_FRAMESKIP_DEC) || (MenuOption > 0 && pPenDown && RctPtInRectangle(pScreenX,pScreenY,&StatusBar.RectStat[7]) && !decfs))
    {
        if (This.m_bAutoFrameskip)
        {
            This.m_bAutoFrameskip = FALSE;
            This.m_nFrameSkip     = FRAMESKIP_LEVELS - 1;
        }
        else
        {
            if (This.m_nFrameSkip == 0)
                This.m_bAutoFrameskip = TRUE;
            else
                This.m_nFrameSkip--;
        }

        if (This.m_bShowFPS == FALSE)
            This.m_nShowFPSTemp = 2 * Machine->drv->frames_per_second;

        /* reset the frame counter every time the frameskip key is pressed, so */
        /* we'll measure the average FPS on a consistent status. */
        This.frames_displayed = 0;
        decfs = 1;
    }

    /*
        Toggle throttle.
    */
    if (input_ui_pressed(IPT_UI_THROTTLE))
    {
        This.m_bThrottled = (This.m_bThrottled == TRUE) ? FALSE : TRUE;

        /* reset the frame counter every time the throttle key is pressed, so */
        /* we'll measure the average FPS on a consistent status. */
        This.frames_displayed = 0;
    }
    
    //Volume up
    if (MenuOption > 0 && pPenDown && RctPtInRectangle(pScreenX,pScreenY,&StatusBar.RectStat[9]) && !volup)
    {
    	int tempvol = snd_stream_vol;
    	tempvol += 50;
    	if (tempvol > 32000)
    		tempvol = 32000;
    	
    	snd_stream_vol = tempvol;
    	SndStreamSetVolume(snd_stream,snd_stream_vol);			

    	volup = 1;
    }
    //Volume down
    if (MenuOption > 0 && pPenDown && RctPtInRectangle(pScreenX,pScreenY,&StatusBar.RectStat[10]) && !voldown)
    {
    	int tempvol = snd_stream_vol;
    	tempvol -= 50;
    	if (tempvol <50)
    		tempvol = 50;
    	
    	snd_stream_vol = tempvol;
    	SndStreamSetVolume(snd_stream,snd_stream_vol);			

    	voldown = 1;
    }
    //Volume Mute
    if (MenuOption > 0 && pPenDown && RctPtInRectangle(pScreenX,pScreenY,&StatusBar.RectStat[11]) && !volmute)
    {
    	int tempvol = snd_stream_vol;
    	if (tempvol)
    	{
    		oldvol = tempvol;
    		snd_stream_vol = 0;
    	}
    	else
    	{
    		snd_stream_vol = oldvol;
    		oldvol = 0;
    	}
    	SndStreamSetVolume(snd_stream,snd_stream_vol);			

    	volmute = 1;
    }
    
    if (!pPenDown)
    {
    	volmute = 0;
    	voldown = 0;
    	volup = 0;
    	decfs = 0;
    	incfs = 0;
    	showfps = 0;
    }

    This.m_nFrameskipCounter = (This.m_nFrameskipCounter + 1) % FRAMESKIP_LEVELS;
}


// Set the bitmap to black.
void GD_clearbitmap(struct osd_bitmap* bitmap)
{
    int i;

    for (i = 0; i < bitmap->height; i++)
        memset(bitmap->line[i],0,
               bitmap->width * (bitmap->depth / 8));

    if (bitmap == Machine->scrbitmap)
    {
        extern int bitmap_dirty;
        bitmap_dirty = 1;

        osd_mark_dirty(0, 0, bitmap->width - 1, bitmap->height - 1, 1);
    }
}


void GD_mark_dirty(int x1, int y1, int x2, int y2, int ui)
{
    if (This.m_bUseDirty)
		MarkDirty(x1, y1, x2, y2, ui);
}


int GD_skip_this_frame(void)
{
    static const int skiptable[FRAMESKIP_LEVELS][FRAMESKIP_LEVELS] =
    {
        { 0,0,0,0,0,0,0,0,0,0,0,0 },
        { 0,0,0,0,0,0,0,0,0,0,0,1 },
        { 0,0,0,0,0,1,0,0,0,0,0,1 },
        { 0,0,0,1,0,0,0,1,0,0,0,1 },
        { 0,0,1,0,0,1,0,0,1,0,0,1 },
        { 0,1,0,0,1,0,1,0,0,1,0,1 },
        { 0,1,0,1,0,1,0,1,0,1,0,1 },
        { 0,1,0,1,1,0,1,0,1,1,0,1 },
        { 0,1,1,0,1,1,0,1,1,0,1,1 },
        { 0,1,1,1,0,1,1,1,0,1,1,1 },
        { 0,1,1,1,1,1,0,1,1,1,1,1 },
        { 0,1,1,1,1,1,1,1,1,1,1,1 }
    };

	//assert(0 <= This.m_nFrameSkip && This.m_nFrameSkip < FRAMESKIP_LEVELS);
	//assert(0 <= This.m_nFrameskipCounter && This.m_nFrameskipCounter < FRAMESKIP_LEVELS);

    return skiptable[This.m_nFrameSkip][This.m_nFrameskipCounter];
}


// control keyboard leds or other indicators //
void GD_led_w(int led, int on)
{
//    StatusWrite(led, on & 1);
}

void GD_set_gamma(float gamma)
{
    //assert(OSDDisplay.set_gamma != 0);
	/*if (Machine->scrbitmap->depth == 8)
	{
		if (This.m_dGamma < 0.2) This.m_dGamma = 0.2;
		if (This.m_dGamma > 3.0) This.m_dGamma = 3.0;

		This.m_dGamma = gamma;
		AdjustColorMap();
	}*/
	//AdjustPalette();
}


float GD_get_gamma()
{
    return (float)0;//This.m_dGamma;
}


void GD_set_brightness(int brightness)
{
	//assert(OSDDisplay.set_brightness != 0);
	/*if (Machine->scrbitmap->depth == 8)
	{
		This.m_nBrightness = brightness;
		AdjustColorMap();
	}*/
	//AdjustPalette();
}

int GD_get_brightness()
{
    return 0;//This.m_nBrightness;
}


void GD_save_snapshot()
{
}




/***************************************************************************
    Internal functions
 ***************************************************************************/

//////////////////////////////////////////
//    Draws MAMEBitmap to the display.  //
//////////////////////////////////////////
void DrawToScreen8BitIndex(void)
{
	//int lineloop, pixel;
	//UInt16 *pal16 =This.m_Pal16;
	//UInt16 *src;
	//UInt16 *dest;
	//UInt8 *base;
	

	WinCopyRectangle(offScreenH,oldDrawWinH,&MameScreen,iAdjustBase,0,winPaint);
	
}
#pragma dont_inline on
extern void ARM816FAST(unsigned long *, unsigned long *, UInt16 *, int);

static void DrawToScreen(void)
{
	int lineloop, pixel;
	UInt16 *pal16 =This.m_Pal16;
	UInt16 *src;
	UInt16 *dest;
	UInt8 *base;
	UInt8 *end;
	int tempwidth;
	

	//osd_display_message("8bit");

		if (Machine->drv->video_attributes &VIDEO_SUPPORTS_DIRTY)
		{
  			dest = (UInt16 *)Global_screen;
				src = dest;
				for (lineloop = iminy;
					 lineloop < iheight + iminy;
					 lineloop++)
				{
					dest = src;
					dest += iAdjustBase;
					
					base = (This.m_pMAMEBitmap->line[lineloop]);
					if (IsDirtyLine(lineloop))
					{
						base += iminx; // offset for visible area
						end = dest + iwidth;
						tempwidth=iwidth/8;
						
						ARM816FAST(base, dest, pal16, tempwidth);
						dest+=tempwidth*8;
						base+=tempwidth*8;
						while (dest < end)
								*(dest++) = pal16[*(base++)];
					}
					src += Global_adj_width;
				}
		}			
		else
		{
  			src = (UInt16 *)Global_screen;
				//src = dest;
				for (lineloop = iminy;
					 lineloop < iheight + iminy;
					 lineloop++)
				{
					dest = src;
					dest += iAdjustBase;
					
					base = (This.m_pMAMEBitmap->line[lineloop]);
					base += iminx; // offset for visible area
					end = dest + iwidth;
					tempwidth=iwidth/8;
					
					ARM816FAST(base, dest, pal16, tempwidth);
					dest+=tempwidth*8;
					base+=tempwidth*8;
					while (dest < end)
							*(dest++) = pal16[*(base++)];
					src += Global_adj_width;
				}
		}
}
#pragma dont_inline reset

static void DrawToScreenScale(void)
{
	int lineloop, pixel;
	UInt16 *pal16 =This.m_Pal16;
	UInt16 *src;
	UInt16 *dest;
	UInt8 *base;
	UInt8 *end;
	

	//osd_display_message("8bit");

		if (Machine->drv->video_attributes &VIDEO_SUPPORTS_DIRTY)
		{
  			dest = (UInt16 *)Global_screen;
				src = dest;
				for (lineloop = iminy;
					 lineloop < iheight + iminy;
					 lineloop++)
				{
					dest = src;
					
					base = (This.m_pMAMEBitmap->line[lineloop]);
					if (IsDirtyLine(lineloop))
					{
						base += iminx; // offset for visible area
						end = dest + iwidth;
						while (dest <= end - 8)
						{
							dest[0] = pal16[base[0]];
							dest[1] = pal16[base[1]];
							dest[2] = pal16[base[2]];
							dest[3] = pal16[base[3]];
							dest[4] = pal16[base[4]];
							dest[5] = pal16[base[5]];
							dest[6] = pal16[base[6]];
							dest[7] = pal16[base[7]];
							base += 8;
							dest += 8;
						}
						while (dest < end)
							*(dest++) = pal16[*(base++)];
					}
					src += Global_adj_width;
				}
		}			
		else
		{
  			dest = (UInt16 *)Global_screen;
				src = dest;
				for (lineloop = iminy;
					 lineloop < iheight + iminy;
					 lineloop++)
				{
					dest = src;
					
					base = (This.m_pMAMEBitmap->line[lineloop]);
					base += iminx; // offset for visible area
					end = dest + iwidth;
					while (dest <= end - 8)
					{
						dest[0] = pal16[base[0]];
						dest[1] = pal16[base[1]];
						dest[2] = pal16[base[2]];
						dest[3] = pal16[base[3]];
						dest[4] = pal16[base[4]];
						dest[5] = pal16[base[5]];
						dest[6] = pal16[base[6]];
						dest[7] = pal16[base[7]];
						base += 8;
						dest += 8;
					}
					while (dest < end)
						*(dest++) = pal16[*(base++)];
					src += Global_adj_width;
				}
		}
		fgbZ_filterrender((UInt8 *)(screenBufferP+(iAdjustBase*2)),(UInt8 *)screenBufferScaleP,(UInt32)(screenPitch*2),(UInt32)(OFFSCREEN_BUFFER_WIDTH*2),SCALE_2XSAI,(UInt32)iwidth,(UInt32)iheight,(UInt32)destwidth,(UInt32)destheight);
}

//////////////////////////////////////////
//    Draws MAMEBitmap to the display.  //
//////////////////////////////////////////
static void DrawToScreen16(void)
{
	int lineloop, pixel;
	UInt16 *pal16 =This.m_Pal16;
	UInt16 *src;
	UInt16 *dest;
	UInt16 *base;
	UInt16 *end;
	//osd_display_message("16_bit");

		if (Machine->drv->video_attributes &VIDEO_SUPPORTS_DIRTY)
		{
  			dest = (UInt16 *)Global_screen;
				src = dest;
				for (lineloop = iminy;
					 lineloop < iheight + iminy;
					 lineloop++)
				{
					dest = src;
					dest += iAdjustBase;
					
					base = (This.m_pMAMEBitmap->line[lineloop]);
					if (IsDirtyLine(lineloop))
					{
						base += iminx; // offset for visible area
						end = dest + iwidth;
						while (dest <= end - 8)
						{
							dest[0] = pal16[base[0]];
							dest[1] = pal16[base[1]];
							dest[2] = pal16[base[2]];
							dest[3] = pal16[base[3]];
							dest[4] = pal16[base[4]];
							dest[5] = pal16[base[5]];
							dest[6] = pal16[base[6]];
							dest[7] = pal16[base[7]];
							base += 8;
							dest += 8;
						}
						while (dest < end)
							*(dest++) = pal16[*(base++)];

						
					}
					src += Global_adj_width;
				}
			
		}			
		else
		{
  			dest = (UInt16 *)Global_screen;
				src = dest;
				for (lineloop = iminy;
					 lineloop < iheight + iminy;
					 lineloop++)
				{
					dest = src;
					dest += iAdjustBase;
					
					base = (This.m_pMAMEBitmap->line[lineloop]);
					base += iminx; // offset for visible area
					end = dest + iwidth;
					while (dest <= end - 8)
					{
						dest[0] = pal16[base[0]];
						dest[1] = pal16[base[1]];
						dest[2] = pal16[base[2]];
						dest[3] = pal16[base[3]];
						dest[4] = pal16[base[4]];
						dest[5] = pal16[base[5]];
						dest[6] = pal16[base[6]];
						dest[7] = pal16[base[7]];
						base += 8;
						dest += 8;
					}
					while (dest < end)
						*(dest++) = pal16[*(base++)];

					src += Global_adj_width;
				}
			
		}
	
}
static void DrawToScreen16Scale(void)
{
	int lineloop, pixel;
	UInt16 *pal16 =This.m_Pal16;
	UInt16 *src;
	UInt16 *dest;
	UInt16 *base;
	UInt16 *end;
	//osd_display_message("16_bit");

		if (Machine->drv->video_attributes &VIDEO_SUPPORTS_DIRTY)
		{
  			dest = (UInt16 *)Global_screen;
				src = dest;
				for (lineloop = iminy;
					 lineloop < iheight + iminy;
					 lineloop++)
				{
					dest = src;
					
					base = (This.m_pMAMEBitmap->line[lineloop]);
					if (IsDirtyLine(lineloop))
					{
						base += iminx; // offset for visible area
						end = dest + iwidth;
						while (dest <= end - 8)
						{
							dest[0] = pal16[base[0]];
							dest[1] = pal16[base[1]];
							dest[2] = pal16[base[2]];
							dest[3] = pal16[base[3]];
							dest[4] = pal16[base[4]];
							dest[5] = pal16[base[5]];
							dest[6] = pal16[base[6]];
							dest[7] = pal16[base[7]];
							base += 8;
							dest += 8;
						}
						while (dest < end)
							*(dest++) = pal16[*(base++)];
					}
					src += Global_adj_width;
					//if (!ZScreenStretch)
					//	dest += iAdjustBase;
				}
			
		}			
		else
		{
  			dest = (UInt16 *)Global_screen;
				src = dest;
				for (lineloop = iminy;
					 lineloop < iheight + iminy;
					 lineloop++)
				{
					dest = src;
					
					base = (This.m_pMAMEBitmap->line[lineloop]);
					base += iminx; // offset for visible area
					end = dest + iwidth;
					while (dest <= end - 8)
					{
						dest[0] = pal16[base[0]];
						dest[1] = pal16[base[1]];
						dest[2] = pal16[base[2]];
						dest[3] = pal16[base[3]];
						dest[4] = pal16[base[4]];
						dest[5] = pal16[base[5]];
						dest[6] = pal16[base[6]];
						dest[7] = pal16[base[7]];
						base += 8;
						dest += 8;
					}
					while (dest < end)
						*(dest++) = pal16[*(base++)];
					src += Global_adj_width;
				}
			
		}
		fgbZ_filterrender((UInt8 *)(screenBufferP+(iAdjustBase*2)),(UInt8 *)screenBufferScaleP,(UInt32)(screenPitch*2),(UInt32)(OFFSCREEN_BUFFER_WIDTH*2),SCALE_2XSAI,(UInt32)iwidth,(UInt32)iheight,(UInt32)destwidth,(UInt32)destheight);
}
//////////////////////////////////////////
//    Draws MAMEBitmap to the display.  //
//////////////////////////////////////////
static void DrawToScreen16Direct(void)
{
	int lineloop, pixel;
	UInt16 *pal16 =This.m_Pal16;
	UInt16 *src;
	UInt16 *dest;
	UInt16 *base;
	
	//osd_display_message("16_direct");


		if (Machine->drv->video_attributes &VIDEO_SUPPORTS_DIRTY)
		{
  			dest = (UInt16 *)Global_screen;
				src = dest;
				for (lineloop = iminy;
					 lineloop < iheight + iminy;
					 lineloop++)
				{
					dest = src;
					dest += iAdjustBase;
					
					base = (This.m_pMAMEBitmap->line[lineloop]);
					if (IsDirtyLine(lineloop))
					{
						base += iminx; // offset for visible area
						for (pixel = iwidth; pixel != 0; pixel-=4)
						{
							//if (IsDirty4(pixel,lineloop/*-iminy*/))
							{
								/**dest++ = *base++;
								*dest++ = *base++;
								*dest++ = *base++;
								*dest++ = *base++;
								*dest++ = *base++;
								*dest++ = *base++;
								*dest++ = *base++;
								*dest++ = *base++;*/
								memcpy(dest,base,8);
								dest+=4; base+=4;
							}
							/*else
							{
								dest+=4; base+=4;
							}*/
						}
					}
					src += Global_adj_width;
				}
		}			
		else
		{
  			dest = (UInt16 *)Global_screen;
				src = dest;
				for (lineloop = iminy;
					 lineloop < iheight + iminy;
					 lineloop++)
				{
					dest = src;
					dest += iAdjustBase;
					
					base = (This.m_pMAMEBitmap->line[lineloop]);
					base += iminx; // offset for visible area
					memcpy(dest,base,iwidth*2);
					src += Global_adj_width;
				}
		}
}
static void DrawToScreen16DirectScale(void)
{
	int lineloop, pixel;
	UInt16 *pal16 =This.m_Pal16;
	UInt16 *src;
	UInt16 *dest;
	UInt16 *base;
	
	//osd_display_message("16_direct");


		if (Machine->drv->video_attributes &VIDEO_SUPPORTS_DIRTY)
		{
  			dest = (UInt16 *)Global_screen;
				src = dest;
				for (lineloop = iminy;
					 lineloop < iheight + iminy;
					 lineloop++)
				{
					dest = src;
					
					base = (This.m_pMAMEBitmap->line[lineloop]);
					if (IsDirtyLine(lineloop))
					{
						base += iminx; // offset for visible area
						for (pixel = 0; pixel < (iwidth); pixel+=4)
						{
							//if (IsDirty4(pixel,lineloop/*-iminy*/))
							{
								/**dest++ = *base++;
								*dest++ = *base++;
								*dest++ = *base++;
								*dest++ = *base++;
								*dest++ = *base++;
								*dest++ = *base++;
								*dest++ = *base++;
								*dest++ = *base++;*/
								memcpy(dest,base,8);
								dest+=4; base+=4;
							}
							/*else
							{
								dest+=4; base+=4;
							}*/
						}
					}
					src += Global_adj_width;
				}
		}			
		else
		{
  			dest = (UInt16 *)Global_screen;
				src = dest;
				for (lineloop = iminy;
					 lineloop < iheight + iminy;
					 lineloop++)
				{
					dest = src;
					
					base = (This.m_pMAMEBitmap->line[lineloop]);
					base += iminx; // offset for visible area
					/*for (pixel = 0; pixel < (iwidth); pixel+=8)
					{
							*dest++ = *base++;
							*dest++ = *base++;
							*dest++ = *base++;
							*dest++ = *base++;
							*dest++ = *base++;
							*dest++ = *base++;
							*dest++ = *base++;
							*dest++ = *base++;
					}*/
					memcpy(dest,base,iwidth*2);
					src += Global_adj_width;
				}
		}
		fgbZ_filterrender((UInt8 *)(screenBufferP+(iAdjustBase*2)),(UInt8 *)screenBufferScaleP,(UInt32)(screenPitch*2),(UInt32)(OFFSCREEN_BUFFER_WIDTH*2),SCALE_2XSAI,(UInt32)iwidth,(UInt32)iheight,(UInt32)destwidth,(UInt32)destheight);
}


/****/
//Zodiac Drawing
/****/
//////////////////////////////////////////
//    Draws MAMEBitmap to the display.  //
//////////////////////////////////////////
/*static void ZDrawToScreen(void)
{
	UInt16 *pal16 =This.m_Pal16;
	static int init=0;

	if (This.m_pMAMEBitmap->_private)
	{
  			//HostOpenScreenBuffer();
		if (!init)
		{
				
			aBitmap.size = sizeof(TwGfxBitmapType);
			aBitmap.width = This.m_pMAMEBitmap->width+16;
			aBitmap.height = This.m_pMAMEBitmap->height+16;
			aBitmap.rowBytes = This.m_pMAMEBitmap->width+16;
			aBitmap.pixelFormat = twGfxPixelFormat8bpp;
			aBitmap.data = This.m_pMAMEBitmap->_private;
			aBitmap.palette = pal16;
			destpoint.x =  srcRect.x-8-iminx;
			destpoint.y = srcRect.y-8-iminy;
			init=1;
		}
			
			twGlue->TwGfxDrawBitmap_(screenBufferH, &destpoint, &aBitmap);
  			
  		//HostCloseScreenBuffer();
		twGlue->TwGfxStretchBlt2_(displaySurface,&destRect,screenBufferH,&srcRect,twGfxStretchFast | twGfxStretchSmooth);
	}
}*/
#pragma dont_inline on

static void ZDrawToScreen(void)
{
	int lineloop, pixel;
	UInt16 *pal16 =This.m_Pal16;
	UInt16 *src;
	UInt16 *dest;
	UInt8 *base;
	UInt8 *end;
	int tempwidth;

	if (This.m_pMAMEBitmap->_private)
	{
		if (This.m_bUseDirty && (Machine->drv->video_attributes &VIDEO_SUPPORTS_DIRTY))
		{
  			HostOpenScreenBuffer();
  			dest = (UInt16 *)screenBufferP;
			if (dest)
			{
				src = dest;
				for (lineloop = iminy;
					 lineloop < iheight + iminy;
					 lineloop++)
				{
					dest = src;
					
					base = (This.m_pMAMEBitmap->line[lineloop]);
					if (IsDirtyLine(lineloop))
					{
						base += iminx; // offset for visible area
						
						end = dest + iwidth;
						tempwidth=iwidth/8;
						

						ARM816FAST(base, dest, pal16, tempwidth);
						dest+=tempwidth*8;
						base+=tempwidth*8;
						while (dest < end)
								*(dest++) = pal16[*(base++)];
								
						/*for (pixel = iwidth/4; pixel != 0; pixel--)
						{
							{
								
								*dest++ = pal16[*base++];
								*dest++ = pal16[*base++];
								*dest++ = pal16[*base++];
								*dest++ = pal16[*base++];
							}
						}*/		
								
						

					}
					
					src += OFFSCREEN_BUFFER_WIDTH;
				}
			}
  			HostCloseScreenBuffer();
		}	
		else
		{
  			HostOpenScreenBuffer();
  			dest = (UInt16 *)screenBufferP;
			if (dest)
			{
				src = dest;
				for (lineloop = iminy;
					 lineloop < iheight + iminy;
					 lineloop++)
				{
					dest = src;
					
					base = (This.m_pMAMEBitmap->line[lineloop]);
					base += iminx; // offset for visible area
					end = dest + iwidth;
					tempwidth=iwidth/8;
				
					ARM816FAST(base, dest, pal16, tempwidth);
					dest+=tempwidth*8;
					base+=tempwidth*8;
					while (dest < end)
							*(dest++) = pal16[*(base++)];
					

					src += OFFSCREEN_BUFFER_WIDTH;
				}
			}
  			HostCloseScreenBuffer();
		}			
		//TwGfxPointType aDestPoint = {0,0};
		//twGlue->TwGfxBitBlt_(displaySurface, &aDestPoint, screenBufferH, &srcRect);
		twGlue->TwGfxStretchBlt2_(displaySurface,&destRect,screenBufferH,&srcRect,twGfxStretchFast | twGfxStretchSmooth);
	}
}
#pragma dont_inline reset

//////////////////////////////////////////
//    Draws MAMEBitmap to the display.  //
//////////////////////////////////////////
static void ZDrawToScreen16(void)
{
	int lineloop, pixel;
	UInt16 *pal16 =This.m_Pal16;
	UInt16 *src;
	UInt16 *dest;
	UInt16 *base;
	UInt16 *end;

	if (This.m_pMAMEBitmap->_private)
	{
		if (This.m_bUseDirty && (Machine->drv->video_attributes &VIDEO_SUPPORTS_DIRTY))
		{
  			HostOpenScreenBuffer();
  			dest = (UInt16 *)screenBufferP;
			if (dest)
			{
				src = dest;
				for (lineloop = iminy;
					 lineloop < iheight + iminy;
					 lineloop++)
				{
					dest = src;
					
					base = (This.m_pMAMEBitmap->line[lineloop]);
					if (IsDirtyLine(lineloop))
					{
						base += iminx; // offset for visible area
						end = dest + iwidth;
						while (dest <= end - 8)
						{
							dest[0] = pal16[base[0]];
							dest[1] = pal16[base[1]];
							dest[2] = pal16[base[2]];
							dest[3] = pal16[base[3]];
							dest[4] = pal16[base[4]];
							dest[5] = pal16[base[5]];
							dest[6] = pal16[base[6]];
							dest[7] = pal16[base[7]];
							base += 8;
							dest += 8;
						}
						while (dest < end)
							*(dest++) = pal16[*(base++)];

					}
					src += OFFSCREEN_BUFFER_WIDTH;
				}
			}
  			HostCloseScreenBuffer();
		}	
		else
		{
  			HostOpenScreenBuffer();
  			dest = (UInt16 *)screenBufferP;
			if (dest)
			{
				src = dest;
				for (lineloop = iminy;
					 lineloop < iheight + iminy;
					 lineloop++)
				{
					dest = src;
					
					base = (This.m_pMAMEBitmap->line[lineloop]);
						base += iminx; // offset for visible area
					end = dest + iwidth;
					while (dest <= end - 8)
					{
						dest[0] = pal16[base[0]];
						dest[1] = pal16[base[1]];
						dest[2] = pal16[base[2]];
						dest[3] = pal16[base[3]];
						dest[4] = pal16[base[4]];
						dest[5] = pal16[base[5]];
						dest[6] = pal16[base[6]];
						dest[7] = pal16[base[7]];
						base += 8;
						dest += 8;
					}
					while (dest < end)
						*(dest++) = pal16[*(base++)];

					src += OFFSCREEN_BUFFER_WIDTH;
				}
			}
  			HostCloseScreenBuffer();
		}			
		//TwGfxPointType aDestPoint = {0,0};
		//twGlue->TwGfxBitBlt_(displaySurface, &aDestPoint, screenBufferH, &srcRect);
		twGlue->TwGfxStretchBlt2_(displaySurface,&destRect,screenBufferH,&srcRect,twGfxStretchFast | twGfxStretchSmooth);
	}
}
//////////////////////////////////////////
//    Draws MAMEBitmap to the display.  //
//////////////////////////////////////////
static void ZDrawToScreen16Direct(void)
{
	int lineloop, pixel;
	UInt16 *pal16 =This.m_Pal16;
	UInt16 *src;
	UInt16 *dest;
	UInt16 *base;

	if (This.m_pMAMEBitmap->_private)
	{
		if (This.m_bUseDirty && (Machine->drv->video_attributes &VIDEO_SUPPORTS_DIRTY))
		{
  			//TwGfxLockSurface ( GameApp.displaySurface, (void**)&dest );
  			HostOpenScreenBuffer();
  			dest = (UInt16 *)screenBufferP;
			if (dest)
			{
				src = dest;
				for (lineloop = iminy;
					 lineloop < iheight + iminy;
					 lineloop++)
				{
					dest = src;
					
					base = (This.m_pMAMEBitmap->line[lineloop]);
					if (IsDirtyLine(lineloop))
					{
						base += iminx; // offset for visible area
						for (pixel = iwidth; pixel != 0; pixel-=8)
						{
							if (IsDirty8(pixel,lineloop/*-iminy*/))
							{
								/**dest++ = *base++;
								*dest++ = *base++;
								*dest++ = *base++;
								*dest++ = *base++;
								*dest++ = *base++;
								*dest++ = *base++;
							*dest++ = *base++;
								*dest++ = *base++;*/
								memcpy(dest,base,16);
								dest+=8; base+=8;
							}
							else
							{
								dest+=8; base+=8;
							}
						}
					}
					src += OFFSCREEN_BUFFER_WIDTH;
				}
			}
  			HostCloseScreenBuffer();
		}	
		else
		{
  			HostOpenScreenBuffer();
  			dest = (UInt16 *)screenBufferP;
			if (dest)
			{
				src = dest;
				for (lineloop = iminy;
					 lineloop < iheight + iminy;
					 lineloop++)
				{
					dest = src;
					
					base = (This.m_pMAMEBitmap->line[lineloop]);
						base += iminx; // offset for visible area
					memcpy(dest,base,iwidth*2);
					src += OFFSCREEN_BUFFER_WIDTH;
				}
			}
  			HostCloseScreenBuffer();
		}			
		
				
		twGlue->TwGfxStretchBlt2_(displaySurface,&destRect,screenBufferH,&srcRect,twGfxStretchFast | twGfxStretchSmooth);
	}
}


static void SetPen(int pen, unsigned char red, unsigned char green, unsigned char blue)
{
	RGBColorType pal;

	   	This.m_Pal16[pen] = TwGfxMakeDisplayRGB(red,green,blue);
		
		if (i8bitMode)
		{
			pal.r = red;
			pal.g = green;
			pal.b = blue;
			WinPalette(winPaletteSet, pen, 1, &pal);
		}
}


/*static void SetPaletteColors(void)
{
	//if (This.m_hPalette && This.m_nDepth == 8)
	//	SetPaletteEntries(This.m_hPalette, 0, OSD_NUMPENS, This.m_AdjustedPalette);    
	//if (This.m_nDepth == 8 && This.m_nScreenDepth == 16)
	//{
		int i;

		
		
		
			for (i = 0; i < OSD_NUMPENS; i++)
			{
				This.m_Pal16[i] = MakeDisplayRGB(This.m_PalEntries[i].peRed,This.m_PalEntries[i].peGreen,This.m_PalEntries[i].peBlue);
				
			}
		
	//}
}*/


/*static void AdjustPalette(void)
{
    if (This.m_nDepth == 8)
    {
        UInt16 i;
        
        memcpy(This.m_AdjustedPalette, This.m_PalEntries, OSD_NUMPENS * sizeof(PALETTEENTRY));

        /*for (i = 0; i < OSD_NUMPENS; i++)
        {
            if (i != This.m_nUIPen) // Don't map the UI pen. //
                Display_MapColor(&This.m_AdjustedPalette[i].peRed,
                                 &This.m_AdjustedPalette[i].peGreen,
                                 &This.m_AdjustedPalette[i].peBlue);
        }

        This.m_bUpdatePalette = TRUE;
    }
}*/


static int GetBlackPen(void)
{
    /*if (This.m_nDepth == 8)
    {
        int i;
        for	(i = 0; i < OSD_NUMPENS; i++)
        {
            if (This.m_PalEntries[i].peRed   == 0
            &&  This.m_PalEntries[i].peGreen == 0
            &&  This.m_PalEntries[i].peBlue  == 0)
            {
                return i;
            }
        }
    }*/

    return 0;
}


/*void AdjustColorMap(void)
{
    int i;
    
    for (i = 0; i < OSD_NUMPENS; i++)
    {
        This.m_pColorMap[i] = (unsigned char)((OSD_NUMPENS - 1.0)
                            * (This.m_nBrightness / 100.0)
                            * pow(((double)i / (OSD_NUMPENS - 1.0)), 1.0 / This.m_dGamma));
    }
}*/


/*void Display_MapColor(unsigned char* pRed, unsigned char* pGreen, unsigned char* pBlue)
{
    *pRed   = This.m_pColorMap[(unsigned char)*pRed];
    *pGreen = This.m_pColorMap[(unsigned char)*pGreen];
    *pBlue  = This.m_pColorMap[(unsigned char)*pBlue];
}*/

//#define TICKSPERSECOND 1000
static void Throttle(void)
{
    static const int waittable[FRAMESKIP_LEVELS][FRAMESKIP_LEVELS] =
    {
        { 1,1,1,1,1,1,1,1,1,1,1,1 },
        { 2,1,1,1,1,1,1,1,1,1,1,0 },
        { 2,1,1,1,1,0,2,1,1,1,1,0 },
        { 2,1,1,0,2,1,1,0,2,1,1,0 },
        { 2,1,0,2,1,0,2,1,0,2,1,0 },
        { 2,0,2,1,0,2,0,2,1,0,2,0 },
        { 2,0,2,0,2,0,2,0,2,0,2,0 },
        { 2,0,2,0,0,3,0,2,0,0,3,0 },
        { 3,0,0,3,0,0,3,0,0,3,0,0 },
        { 4,0,0,0,4,0,0,0,4,0,0,0 },
        { 6,0,0,0,0,0,6,0,0,0,0,0 },
        {12,0,0,0,0,0,0,0,0,0,0,0 }
    };
    UInt32 curr;
    UInt32 TICKSPERSECOND;
    int i;
    //int already_synced = 0;
	INT64 MyFRAMESKIP_LEVELS=12;
	if (IsZodiac)
    	TICKSPERSECOND = SysTicksPerSecond()*1000;
    else
    	TICKSPERSECOND = SysTicksPerSecond();

    if (This.m_bThrottled)
    {
		INT64 target,target2;

		if (IsZodiac)
        	curr = twGlue->TwGetMicroSeconds_();
        else
        	curr = TimGetTicks();

		//if (already_synced == 0)
        //{
			/* wait only if the audio update hasn't synced us already */

            /* wait until enough time has passed since last frame... */
			target = This.m_Prev +
				(waittable[This.m_nFrameSkip][This.m_nFrameskipCounter] * TICKSPERSECOND / Machine->drv->frames_per_second);

            /* ... OR since FRAMESKIP_LEVELS frames ago. This way, if a frame takes */
            /* longer than the allotted time, we can compensate in the following frames. */
            target2 = This.m_PrevFrames[This.m_nFrameskipCounter] +
				MyFRAMESKIP_LEVELS * TICKSPERSECOND / Machine->drv->frames_per_second;

                if (target - target2 > 0)
                    target = target2;

		        if (curr - target < 0)
				{
					do
					{
						if (IsZodiac)
				        	curr = twGlue->TwGetMicroSeconds_();
				        else
				        	curr = TimGetTicks();
					} while (curr - target < 0);
				}
         //}
	}
    else
    {
		if (IsZodiac)
        	curr = twGlue->TwGetMicroSeconds_();
        else
        	curr = TimGetTicks();
    }

    /* for the FPS average calculation */
    if (++This.frames_displayed == FRAMES_TO_SKIP)
        This.start_time = curr;
    else
        This.end_time = curr;

    if (This.m_nFrameskipCounter == 0 && (curr - This.m_PrevFrames[This.m_nFrameskipCounter]))
    {
        UInt32 divdr;

        divdr = Machine->drv->frames_per_second * (curr - This.m_PrevFrames[This.m_nFrameskipCounter]) / (100 * MyFRAMESKIP_LEVELS);
		if (divdr == 0)
			divdr = 1;
		This.m_nSpeed = MAMEApp.m_nSpeed = (int)((TICKSPERSECOND + divdr / 2) / divdr);
    }

    This.m_Prev = curr;
    for (i = 0; i < waittable[This.m_nFrameSkip][This.m_nFrameskipCounter]; i++)
        This.m_PrevFrames[(This.m_nFrameskipCounter + MyFRAMESKIP_LEVELS - i) % MyFRAMESKIP_LEVELS] = curr;

    This.m_nVecFrameCount += waittable[This.m_nFrameSkip][This.m_nFrameskipCounter];
    if (This.m_nVecFrameCount >= Machine->drv->frames_per_second)
    {
        extern int vector_updates; /* avgdvg_go()'s per Mame frame, should be 1 */

        This.m_nVecFrameCount = 0;
        This.m_nVecUPS = vector_updates;
        vector_updates = 0;
    }

    /*
        Show frames per second.
    */
    if (This.m_bShowFPS || This.m_nShowFPSTemp != 0 /* || This.m_bAviCapture*/)
    {
        int fps;
        int divdr;
		char buf[32];

        divdr = 100 * MyFRAMESKIP_LEVELS;
        fps = (Machine->drv->frames_per_second * (FRAMESKIP_LEVELS - This.m_nFrameSkip) * This.m_nSpeed + (divdr / 2)) / divdr;
        
		// Fix Show Framerate - Techmaster
		sprintf(buf,"%2d%3d%%(%2d/%.0f)    ",This.m_nFrameSkip,This.m_nSpeed,fps,Machine->drv->frames_per_second);
		ui_text(buf,Machine->uiwidth-strlen(buf)*Machine->uifontwidth,0);
	}
}


//
//  Update the display.
//
static void DrawIcons(void)
{
	UInt16 *src;
	UInt16 *dest;
	int XAdjust = screenWidth-24;
	int lineloop,pixels, count;
	
	if (IsZodiac)
		twGlue->TwGfxLockSurface_(displaySurface, (void**)&dest);
	else
  		dest = screenBufferP;

	if (MenuOption == 2)
	{

		//Vertical Menu
		dest += XAdjust;
		for (count = 0;count<13;count++)
		{
			src = StatusBar.StatIcons[count].rowbytes;
			
			for ( lineloop = 0;lineloop<24;lineloop++)
			{
				for (pixels = 0;pixels<24;pixels++)
					*dest++ = *src++;
					
				dest+=XAdjust;
			}
		}
			
			
			for ( lineloop = 7;lineloop>=0;lineloop--)
			{
				src = StatusBar.StatIcons[12+BatteryIcon].rowbytes;
				src+=lineloop;
				for (pixels = 0;pixels<24;pixels++)
				{
					*dest++ = *src;
					src+=8;
				}
					
				dest+=XAdjust;
			}

	}
	else
	{
		//Horizontal bar (bottom of screen?)
		XAdjust = screenWidth-(24*13)-(1*8);
		
		//Skip to the bottom of the screen
		dest+= screenWidth * (screenHeight-24);
		
		for (lineloop = 0;lineloop<24;lineloop++)
		{
			for (count = 0;count<13;count++)
			{
				src = StatusBar.StatIcons[count].rowbytes;
				src += lineloop * 24;
					for (pixels = 0;pixels<24;pixels++)
						*dest++ = *src++;
				
			}
				src = StatusBar.StatIcons[12+BatteryIcon].rowbytes;
				src += lineloop * 8 ;
					for (pixels = 0;pixels<8;pixels++)
						*dest++ = *src++;
			dest+=XAdjust;
		}
	}


}
static void ConvertIcons16to8()
{
	int count, pixel_loop, lineloop;
	
	//osd_display_message("Converting Icons");
	if (MenuOption == 1)
	{
		//loop through all icons
		for (count = 0;count<16;count++)
		{
			int iconheight;
			int iconwidth;
			UInt16 *src;
			UInt8 *dest;
			Err err;
			
			StatusBar8.StatIcons[count].bmWidth = StatusBar.StatIcons[count].bmWidth;
			StatusBar8.StatIcons[count].bmHeight = StatusBar.StatIcons[count].bmHeight;
			RctCopyRectangle(&StatusBar.RectStat[count],&StatusBar8.RectStat[count]);
			StatusBar8.StatIcons[count].rowbytes = malloc(StatusBar8.StatIcons[count].bmHeight * StatusBar8.StatIcons[count].bmWidth);
			
			src = StatusBar.StatIcons[count].rowbytes;
			dest = StatusBar8.StatIcons[count].rowbytes;
			
			for (pixel_loop = 0;pixel_loop < StatusBar8.StatIcons[count].bmHeight * StatusBar8.StatIcons[count].bmWidth;pixel_loop++)
			{
				RGBColorType color;
				color.index = 0;
				color.r = (*src >> 8);
				//color.r = color.r && twGfxRMask;
				color.g = (*src >> 3);
				//color.g = color.g && twGfxGMask;
				color.b = (*src << 3);
				//color.b = color.b && twGfxBMask;
				*dest++ = WinRGBToIndex(&color);
				src++;
			}
			StatusBar8.StatBitmapLow[count] = BmpCreate(StatusBar8.StatIcons[count].bmWidth, StatusBar8.StatIcons[count].bmHeight, 8, NULL, &err);
			StatusBar8.StatBitmap[count] = BmpCreateBitmapV3(StatusBar8.StatBitmapLow[count], kDensityDouble,  StatusBar8.StatIcons[count].rowbytes,NULL);
		
		}
	}
	else //need to rotate the last one (battery)
	{
		//loop through all icons except the last 3
		for (count = 0;count<13;count++)
		{
			int iconheight;
			int iconwidth;
			UInt16 *src;
			UInt8 *dest;
			Err err;
			
			StatusBar8.StatIcons[count].bmWidth = StatusBar.StatIcons[count].bmWidth;
			StatusBar8.StatIcons[count].bmHeight = StatusBar.StatIcons[count].bmHeight;
			RctCopyRectangle(&StatusBar.RectStat[count],&StatusBar8.RectStat[count]);
			StatusBar8.StatIcons[count].rowbytes = malloc(StatusBar8.StatIcons[count].bmHeight * StatusBar8.StatIcons[count].bmWidth);
			
			src = StatusBar.StatIcons[count].rowbytes;
			dest = StatusBar8.StatIcons[count].rowbytes;
			
			for (pixel_loop = 0;pixel_loop < StatusBar8.StatIcons[count].bmHeight * StatusBar8.StatIcons[count].bmWidth;pixel_loop++)
			{
				RGBColorType color;
				color.index = 0;
				color.r = (*src >> 8);
				color.g = (*src >> 3);
				color.b = (*src << 3);
				*dest++ = WinRGBToIndex(&color);
				src++;
			}
			StatusBar8.StatBitmapLow[count] = BmpCreate(StatusBar8.StatIcons[count].bmWidth, StatusBar8.StatIcons[count].bmHeight, 8, NULL, &err);
			StatusBar8.StatBitmap[count] = BmpCreateBitmapV3(StatusBar8.StatBitmapLow[count], kDensityDouble,  StatusBar8.StatIcons[count].rowbytes,NULL);
		
		}
		
		for (count = 13;count < 16; count++)
		{
			UInt16 *src;
			UInt8 *dest;
			Err err;
			int pixels;
			
			StatusBar8.StatIcons[count].bmWidth = StatusBar.StatIcons[count].bmWidth;
			StatusBar8.StatIcons[count].bmHeight = StatusBar.StatIcons[count].bmHeight;
			RctCopyRectangle(&StatusBar.RectStat[count],&StatusBar8.RectStat[count]);
			StatusBar8.StatIcons[count].rowbytes = malloc(StatusBar8.StatIcons[count].bmHeight * StatusBar8.StatIcons[count].bmWidth);
			dest = StatusBar8.StatIcons[count].rowbytes;
			for (lineloop = 7;lineloop>=0;lineloop--)
			{
				
				
				src = StatusBar.StatIcons[count].rowbytes;
				
				src += lineloop;
				for (pixels = 0;pixels<24;pixels++)
				{
					RGBColorType color;
					color.index = 0;
					color.r = (*src >> 8);
					color.g = (*src >> 3);
					color.b = (*src << 3);
					*dest++ = WinRGBToIndex(&color);
					src+=8;
				}
				
			}
			StatusBar8.StatBitmapLow[count] = BmpCreate(StatusBar8.StatIcons[count].bmHeight, StatusBar8.StatIcons[count].bmWidth, 8, NULL, &err);
			StatusBar8.StatBitmap[count] = BmpCreateBitmapV3(StatusBar8.StatBitmapLow[count], kDensityDouble,  StatusBar8.StatIcons[count].rowbytes,NULL);

		}
		
	}
	
	
}

static void DrawIcons8(void)
{

	int count;
	
	for (count = 0;count<13;count++)
	{
		if (StatusBar8.StatBitmap[count])
			WinPaintBitmap(StatusBar8.StatBitmap[count],StatusBar8.RectStat[count].topLeft.x, StatusBar8.RectStat[count].topLeft.y);
	}
	if (StatusBar8.StatBitmap[12 + BatteryIcon])
		WinPaintBitmap(StatusBar8.StatBitmap[12 + BatteryIcon],StatusBar8.RectStat[12 + BatteryIcon].topLeft.x, StatusBar8.RectStat[12 + BatteryIcon].topLeft.y);

}
static void DrawBatteryIcon8()
{
		WinPaintBitmap(StatusBar8.StatBitmap[12 + BatteryIcon],StatusBar8.RectStat[12 + BatteryIcon].topLeft.x, StatusBar8.RectStat[12 + BatteryIcon].topLeft.y);
}
static void DrawBatteryIcon()
{
	UInt16 *src;
	UInt16 *dest;
	int XAdjust = screenWidth-24;
	int lineloop,pixels, count;

	if (IsZodiac)
		twGlue->TwGfxLockSurface_(displaySurface, (void**)&dest);
	else
  		dest = screenBufferP;

	if (MenuOption == 2)
	{

		//Vertical Menu
		dest += screenWidth*24*13 + XAdjust;//12 icons 24 pixels high each
		
			
			for ( lineloop = 7;lineloop>=0;lineloop--)
			{
				src = StatusBar.StatIcons[12+BatteryIcon].rowbytes;
				src+=lineloop;
				for (pixels = 0;pixels<24;pixels++)
				{
					*dest++ = *src;
					src+=8;
				}
					
				dest+=XAdjust;
			}

	}
	else
	{
		//Horizontal bar (bottom of screen?)
		XAdjust = screenWidth-(24*13)-(1*8);
		
		//Skip to the bottom of the screen
		dest+= screenWidth * (screenHeight-24);
		
		for (lineloop = 0;lineloop<24;lineloop++)
		{
			/*for (count = 0;count<13;count++)
			{
				src = StatusBar.StatIcons[count].rowbytes;
				src += lineloop * 24;
					for (pixels = 0;pixels<24;pixels++)
						*dest++ = *src++;
				
			}*/
			dest+=24*13;
				src = StatusBar.StatIcons[12+BatteryIcon].rowbytes;
				src += lineloop * 8 ;
					for (pixels = 0;pixels<8;pixels++)
						*dest++ = *src++;
			dest+=XAdjust;
		}
	}


}


static void update_display(void)
{
	//static Int32 ticks, fticks;
	static int ticks=0;
	static int batterychanged=0;
	static int oldbattery = 3;
	//UInt16 temp;

	profiler_mark(PROFILER_BLIT);
	if (This.m_pMAMEBitmap->_private)
		drawtoscreen();

    if (!ticks)
    {
    	if (MenuOption > 0)
			drawicons();
	}
    ticks++;
    
	 if (ticks == 3600 && MenuOption >0)
	 {
	 	UInt16 warnThresholdP;
		UInt16 criticalThresholdP;
		Int16 maxTicksP;
		SysBatteryKind kindP;
		Boolean pluggedIn;

	 	ticks = 1;
		if (batterychanged && MenuOption >0)
		{ 
			drawbattery();
			oldbattery = BatteryIcon;
			batterychanged = 0;
		}
			
	 	//EvtResetAutoOffTimer();
	 	SysBatteryInfoV40 (false,&warnThresholdP,&criticalThresholdP,
	 							&maxTicksP,&kindP,&pluggedIn,&batteryPercent);
	 	if (batteryPercent > 66)
	 		BatteryIcon = 3;
	 	else if (batteryPercent > 33)
	 		BatteryIcon =2;
	 	else
	 		BatteryIcon = 1;
	 		
	 	if (BatteryIcon != oldbattery)
	 		batterychanged = 1;
	 }
	profiler_mark(PROFILER_END);    
}



#ifdef PNG_SAVE_SUPPORT

void Display_WriteBitmap(struct osd_bitmap* tBitmap, PALETTEENTRY* pPalEntries)
{
	//removed not used in MameCE
}
#endif

