/***************************************************************************

    M.A.M.E.CE3  -  Multiple Arcade Machine Emulator for Pocket PC
    Win32 Portions Copyright (C) 1997-98 Michael Soderstrom and Chris Kirmse
    
    This file is part of MAMECE3, and may only be used, modified and
    distributed under the terms of the MAME license, in "MAME.txt".
    By continuing to use, modify or distribute this file you indicate
    that you have read the license and understand and accept it fully.

 ***************************************************************************/

/***************************************************************************

  ZSound.c

 ***************************************************************************/
#include "HostPalm.h"
#include "Playgame.h"
#include "ZSound.h"
#include "endianutils.h"
#include "mixer.h"

/***************************************************************************
    function prototypes
 ***************************************************************************/


static int      ZSound_init(void);
static void     ZSound_exit(void);

static int      ZSound_start_audio_stream(int stereo);
static int      ZSound_update_audio_stream(INT16* buffer);
static void     ZSound_stop_audio_stream(void);

static void     ZSound_set_mastervolume(int volume);
static int      ZSound_get_mastervolume(void);
static void     ZSound_sound_enable(int enable);
static void     ZSound_update_audio(void);
static Err StreamCallback (void *userData, SndStreamRef Zstream,
		              void *buffer, UInt32 bufferSizeP);

void     ZSound_opl_control(int chip,int reg);
void     ZSound_opl_write(int chip,int data);
UInt32 PALM_WriteBytes(Int16 *buffer, UInt32 *bufsize);

static int GlobalStereo;
/***************************************************************************
    External variables
 ***************************************************************************/

struct OSDSound ZSound = 
{
    { ZSound_init },                     /* init                    */
    { ZSound_exit },					  /* exit                    */
	{ ZSound_start_audio_stream },		  /* start the audio stream  */
    { NULL/*ZSound_update_audio_stream*/ },	  /* update the audio stream */
    { ZSound_stop_audio_stream },        /* stop the audio stream	 */
	{ ZSound_set_mastervolume },         /* set_mastervolume        */
    { ZSound_get_mastervolume },         /* get_mastervolume        */
    { ZSound_sound_enable },             /* sound_enable            */
    { ZSound_update_audio },	          /* update_audio            */
 	{ ZSound_opl_control },			  /* opl_control			 */
	{ ZSound_opl_write }				  /* opl_write				 */
};

/***************************************************************************
    Internal structures
 ***************************************************************************/

struct tSound_private
{
	int				m_nVolume;		// -32 to 0 attenuation value
	int				m_nSampleRate;

    UInt32          m_nSamplesPerFrame;
    UInt32          m_nBytesPerFrame;
};

/***************************************************************************
    Internal variables
 ***************************************************************************/

static struct tSound_private      This;

/***************************************************************************
    External OSD functions  
 ***************************************************************************/


SndStreamRef snd_stream=NULL;
Int32 snd_stream_vol;

//AK - define to create debug log for sound stream.
//#define DEBUGTESTING

//fg
//We use a round robbin style buffer so that we can keep feeding the 
//mixer, which itself uses two internal buffers. Probably only need
//3 buffers but the cost of extras is low.
//6000 size comes from minimum frame rate of 30fps at 44100, in stereo, 16bit data.
unsigned char *mybuffer[MAX_BUFFERS];
int mybuffer_flag[MAX_BUFFERS];
static int mybuffer_leftover[MAX_BUFFERS];
static int readbuffer;
int writebuffer;

typedef struct {uint32 __r9;uint32 __r10;} reg_sys_t;
static reg_sys_t reg_sys;


static Err PALM_sndCallBack (void *userData,SndStreamRef stream, void *bufferZ,UInt32 *byteCountZ)
{
#ifndef WIN32
	__asm 
	{
		stmfd  r13!,{r9,r10}
		ldr	   r9,[r0]
		ldr	   r10,[r0,#4]
	}	
#endif
	*byteCountZ = PALM_WriteBytes(bufferZ, byteCountZ);
#ifndef WIN32
	__asm 
	{
		ldmfd  r13!,{r9,r10}
	}
#endif
	return errNone;
}
//#pragma optimization_level 0
//#pragma dont_inline on

static BOOL PALM_Init(void)
{
#ifdef DEBUGTESTING	
	debugs("PALM_Init start");
#endif

	snd_stream_vol=850;	
	
#ifndef WIN32
	__asm 
  {
  	ldr  r0, = reg_sys
  	add	 r0,r0,r10
  	str	 r9,[r0]
  	str	 r10,[r0,#4]
  } 
#endif


//AK - Zodiac hack - don't want TwGlue version
#ifdef SndStreamCreateExtended
#undef SndStreamCreateExtended
#endif

	//Create Sound Stream using Extended version so we can tell it how
	//much data we will send it. Need to use 44100 for perfect sound
	//as MAME engine seems to prefer this frequency.
	//The __asm code is needed for the TNA/PNO to work properly as it
	//grants access to the global variables. Hacky but it works well.

	SndStreamCreateExtended(&snd_stream,sndOutput,
							sndFormatPCM, Machine->sample_rate, 
							sndInt16Opposite, GlobalStereo, 
							PALM_sndCallBack, &reg_sys, 
							/*This.m_nSamplesPerFrame*/ 4096,true);
		
	SndStreamSetVolume(snd_stream,snd_stream_vol);			

#ifdef DEBUGTESTING	
	debugs("PALM_Init end");
#endif

	return true;
}

static int ZSound_init(void)
{
	This.m_nVolume = 0;
	This.m_nSampleRate = Machine->sample_rate; 

	return 0;  //Sound Init always successful
}


static void ZSound_exit(void)
{
	int i;

#ifdef DEBUGTESTING	
	debugs("ZSound_exit start");
#endif

	ZSound_stop_audio_stream();
	
	if (snd_stream) 
	{		
		SndStreamDelete(snd_stream);
		snd_stream=NULL;
	}

	for(i=0;i<MAX_BUFFERS;i++)
		free(mybuffer[i]);
		
#ifdef DEBUGTESTING	
	debugs("ZSound_exit end");
	debugfclose();
#endif

}


int ZSound_start_audio_stream(int stereo)
{
	int i; 

#ifdef DEBUGTESTING	
	debugs("ZSound_start_audio_stream start");
#endif

	if (Machine->sample_rate == 0)
		return 0;

    if (stereo)
        stereo = 1;	// make sure it's either 0 or 1 
        
    GlobalStereo = stereo;

	// determine the number of samples and bytes per frame //
	This.m_nSamplesPerFrame = Machine->sample_rate / Machine->drv->frames_per_second;
	This.m_nBytesPerFrame   = This.m_nSamplesPerFrame * sizeof(INT16) * (stereo + 1);

	for(i=0;i<MAX_BUFFERS;i++)
	{
		mybuffer_flag[i]=0;
		mybuffer_leftover[i]=0;
   		mybuffer[i]=malloc(MAX_BUFFER_SIZE);
		memset(mybuffer[i], 0, MAX_BUFFER_SIZE);	}

	readbuffer=0;
	writebuffer=0;

	PALM_Init();
	if (snd_stream) SndStreamStart(snd_stream);				

#ifdef DEBUGTESTING	
	debugs("ZSound_start_audio_stream end");
#endif


	return This.m_nSamplesPerFrame;	
}

UInt32 PALM_WriteBytes(Int16 *buffer, UInt32 *bufsize)
{
	//PalmOS Sound Stream only seems to have a maximum
	//buffer of 4K which causes a problem for something like
	//tapper that has a Frame byte size of 5880.
	//Process what bytes we can then save the rest for the next
	//call. Callback will do this multiple times anyway before
	//the next MAME sound mixer call anyway.

	UInt32 actsize=*bufsize;
#ifdef DEBUGTESTING	
	static Int16 *testing=0;
	if ((Int16 *)testing != buffer)
	{
		debugu32(buffer);
		testing = buffer;
	}
#endif
	profiler_mark(PROFILER_SOUND);

	//Get sound from the round robbin buffer if it has been filled.
	if(mybuffer_flag[readbuffer] || mybuffer_leftover[readbuffer])
	{
		if(mybuffer_leftover[readbuffer])
		{
			actsize = min(mybuffer_leftover[readbuffer],*bufsize);
			mybuffer_leftover[readbuffer]=0;
			mybuffer_flag[readbuffer]=0;
			memcpy(buffer, mybuffer[readbuffer]+(This.m_nBytesPerFrame - actsize), actsize);
			readbuffer++;

		}
		else
		{
			if(actsize < This.m_nBytesPerFrame)
			{
				memcpy(buffer, mybuffer[readbuffer], actsize);
				mybuffer_leftover[readbuffer]=This.m_nBytesPerFrame - actsize;
			}
			else
			{
				mybuffer_flag[readbuffer]=0;
				memcpy(buffer, mybuffer[readbuffer], This.m_nBytesPerFrame);
				actsize = This.m_nBytesPerFrame;
				readbuffer++;
			}
		}

		if(readbuffer >= MAX_BUFFERS)
			readbuffer=0;
	}
	else
	{
		//Must write something here or Zodiac Hardware will freeze
		if(actsize > This.m_nBytesPerFrame)
			actsize = This.m_nBytesPerFrame;
		memset(buffer, 0, actsize);
	}
	profiler_mark(PROFILER_END);
	
#ifdef DEBUGTESTING	
	if (actsize > *bufsize)
	{
		debugs("Warning actsize>bufsize!");
		debugu32(actsize);
		debugu32(*bufsize);
	}
#endif	

	//Extended sound stream wants the value in bytes written
	return actsize;
}


/*int ZSound_update_audio_stream(INT16* buffer)
{
	profiler_mark(PROFILER_SOUND);
	
	//Wait until buffer has been read by callback
	if(!mybuffer_flag[writebuffer])
	{
	    memcpy(mybuffer[writebuffer], buffer, This.m_nBytesPerFrame);
	    mybuffer_flag[writebuffer]=1;
	    writebuffer++;
	    if(writebuffer >= MAX_BUFFERS)
	        writebuffer=0;
	    profiler_mark(PROFILER_END);
		return This.m_nSamplesPerFrame;
	}
	else
	{
		profiler_mark(PROFILER_END);
		return 0;
	}

}*/


void    ZSound_stop_audio_stream(void)
{
#ifdef DEBUGTESTING	
	debugs("ZSound_stop_audio_stream start");
#endif

	if (snd_stream) SndStreamStop(snd_stream);	
#ifdef DEBUGTESTING	
	debugs("ZSound_stop_audio_stream end");
#endif
	
}


static void ZSound_set_mastervolume(int volume)
{
	This.m_nVolume = volume;
}


static int ZSound_get_mastervolume(void)
{
    return This.m_nVolume;
}


static void ZSound_sound_enable(int enable)
{
	;
}


static void ZSound_update_audio(void)
{
	;
}


void ZSound_opl_control(int chip,int reg)
{
    // removed no OPL in CE
}

void ZSound_opl_write(int chip,int data)
{
   // removed no opl in CE
}
//#pragma dont_inline reset 
//#pragma optimization_level reset

