#include<stdio.h>
#include<stdlib.h>
#include<string.h>

#include "driver.h"
#include "cpuintrf.h"
#include "memory.h"
#include "z80.h"
#include "cz80.h"

cz80_struc mame4all_cz80_struc;

int z80_ICount;

#if CZ80_USE_WORD_HANDLER
static void my_writemem16(unsigned int address, unsigned int data)
{
	cpu_writemem16(address,(unsigned char)data&0xff);
	cpu_writemem16(address+1,((unsigned char)(data>>8))&0xff);
}
static unsigned short my_readmem16(unsigned int address)
{
	return (((cpu_readmem16(address))&0xFF)|((cpu_readmem16(address+1)&0xff)<<8));
}
#endif

static int cpu_cz80_irq_callback(int param)
{
//printf("cpu_z80_irq_callback %i\n",param); fflush(stdout);
	return param;
}

static void cpu_cz80_reti_callback(void)
{
//	puts("cpu_z80_reti_callback"); fflush(stdout);
}

void z80_reset(void *daisy_chain)
{
//puts("Z80_Reset"); fflush(stdout);
if (daisy_chain)
{
puts(" Caution !!! Z80_DaisyChain not implementated yet !!!");fflush(stdout);
}
	Cz80_Init(&mame4all_cz80_struc);
	Cz80_Set_Fetch(&mame4all_cz80_struc,0x0000,0xFFFF,(unsigned)OP_ROM);
	Cz80_Set_ReadB(&mame4all_cz80_struc,(CZ80_READ *)&cpu_readmem16);
	Cz80_Set_WriteB(&mame4all_cz80_struc,(CZ80_WRITE *)&cpu_writemem16);
#if CZ80_USE_WORD_HANDLER
	Cz80_Set_ReadW(&mame4all_cz80_struc,&my_readmem16);
	Cz80_Set_WriteW(&mame4all_cz80_struc,&my_writemem16);
#endif
	Cz80_Set_INPort(&mame4all_cz80_struc,(CZ80_READ *)&cpu_readport);
	Cz80_Set_OUTPort(&mame4all_cz80_struc,(CZ80_WRITE *)&cpu_writeport);
	Cz80_Set_IRQ_Callback(&mame4all_cz80_struc,cpu_cz80_irq_callback);
	Cz80_Set_RETI_Callback(&mame4all_cz80_struc,cpu_cz80_reti_callback);
	Cz80_Reset(&mame4all_cz80_struc);
}

unsigned z80_get_context(void *Regs)
{
	if (Regs)
		memcpy(Regs,(void *)&mame4all_cz80_struc,sizeof(cz80_struc));
	return sizeof(Z80_Regs);

}

void z80_set_context (void *Regs)
{
	memcpy((void *)&mame4all_cz80_struc,Regs,sizeof(cz80_struc));
}

unsigned z80_get_pc (void)
{
//printf("Z80_GetPC = %.4X\n",Cz80_Get_PC(&mame4all_cz80_struc)); fflush(stdout);
	return Cz80_Get_PC(&mame4all_cz80_struc);
}

void Z80_Cause_Interrupt(int type)
{
//printf("Z80_Cause_Interrupt %i\n",type); fflush(stdout);
	if (type == Z80_NMI_INT)
		Cz80_Set_NMI(&mame4all_cz80_struc);
	else if (type >= 0)
		Cz80_Set_IRQ(&mame4all_cz80_struc, type & 0xff);
}

void Z80_Clear_Pending_Interrupts(void)
{
//puts("Z80_Clear_Pending_Interrupts"); fflush(stdout);
	Cz80_Clear_IRQ(&mame4all_cz80_struc);
	Cz80_Clear_NMI(&mame4all_cz80_struc);
}

int z80_execute(int cycles)
{
/*
//printf("Z80_Execute %i\n",cycles); fflush(stdout);
int faltan=cycles;
while(faltan>0)
{
faltan-=Cz80_Exec(&mame4all_cz80_struc,10);
}
//puts("-"); fflush(stdout);
return cycles-faltan;
*/
	return Cz80_Exec(&mame4all_cz80_struc,cycles);
}
void z80_burn(int cycles){}
void z80_exit (void){}
unsigned z80_get_reg (int regnum){}
void z80_set_reg (int regnum, unsigned val){}
unsigned z80_get_sp (void){}
void z80_set_sp (unsigned val){}
void z80_set_irq_line(int irqline, int state){}
void z80_state_save(void *file){}
void z80_state_load(void *file){}
void z80_set_nmi_line(int state){}
void z80_set_pc (unsigned val){}

void z80_set_irq_callback(int (*irq_callback)(int))
{
	Cz80_Set_IRQ_Callback(&mame4all_cz80_struc,irq_callback);

}

/****************************************************************************
 * Return a formatted string for a register
 ****************************************************************************/
const char *z80_info(void *context, int regnum)
{
	static char buffer[32][47+1];
	static int which = 0;
	Z80_Regs *r = context;

	which = ++which % 32;
    buffer[which][0] = '\0';
	if( !context )
		r = &mame4all_cz80_struc;

    switch( regnum )
	{
		case CPU_INFO_REG+Z80_PC: sprintf(buffer[which], "PC:%04X", r->PC.w.l); break;
		case CPU_INFO_REG+Z80_SP: sprintf(buffer[which], "SP:%04X", r->SP.w.l); break;
		case CPU_INFO_REG+Z80_AF: sprintf(buffer[which], "AF:%04X", r->AF.w.l); break;
		case CPU_INFO_REG+Z80_BC: sprintf(buffer[which], "BC:%04X", r->BC.w.l); break;
		case CPU_INFO_REG+Z80_DE: sprintf(buffer[which], "DE:%04X", r->DE.w.l); break;
		case CPU_INFO_REG+Z80_HL: sprintf(buffer[which], "HL:%04X", r->HL.w.l); break;
		case CPU_INFO_REG+Z80_IX: sprintf(buffer[which], "IX:%04X", r->IX.w.l); break;
		case CPU_INFO_REG+Z80_IY: sprintf(buffer[which], "IY:%04X", r->IY.w.l); break;
		case CPU_INFO_REG+Z80_R: sprintf(buffer[which], "R:%02X", (r->R & 0x7f) | (r->R2 & 0x80)); break;
		case CPU_INFO_REG+Z80_I: sprintf(buffer[which], "I:%02X", r->I); break;
		case CPU_INFO_REG+Z80_AF2: sprintf(buffer[which], "AF'%04X", r->AF2.w.l); break;
		case CPU_INFO_REG+Z80_BC2: sprintf(buffer[which], "BC'%04X", r->BC2.w.l); break;
		case CPU_INFO_REG+Z80_DE2: sprintf(buffer[which], "DE'%04X", r->DE2.w.l); break;
		case CPU_INFO_REG+Z80_HL2: sprintf(buffer[which], "HL'%04X", r->HL2.w.l); break;
		case CPU_INFO_REG+Z80_IM: sprintf(buffer[which], "IM:%X", r->IM); break;
		case CPU_INFO_REG+Z80_IFF1: sprintf(buffer[which], "IFF1:%X", r->IFF1); break;
		case CPU_INFO_REG+Z80_IFF2: sprintf(buffer[which], "IFF2:%X", r->IFF2); break;
		case CPU_INFO_REG+Z80_HALT: sprintf(buffer[which], "HALT:%X", r->HALT); break;
		case CPU_INFO_REG+Z80_NMI_STATE: sprintf(buffer[which], "NMI:%X", r->nmi_state); break;
		case CPU_INFO_REG+Z80_IRQ_STATE: sprintf(buffer[which], "IRQ:%X", r->irq_state); break;
        case CPU_INFO_FLAGS:
			sprintf(buffer[which], "%c%c%c%c%c%c%c%c",
				r->AF.b.l & 0x80 ? 'S':'.',
				r->AF.b.l & 0x40 ? 'Z':'.',
				r->AF.b.l & 0x20 ? '5':'.',
				r->AF.b.l & 0x10 ? 'H':'.',
				r->AF.b.l & 0x08 ? '3':'.',
				r->AF.b.l & 0x04 ? 'P':'.',
				r->AF.b.l & 0x02 ? 'N':'.',
				r->AF.b.l & 0x01 ? 'C':'.');
			break;
		case CPU_INFO_NAME: return "Z80";
        case CPU_INFO_FAMILY: return "Zilog Z80";
		case CPU_INFO_VERSION: return "2.7";
		case CPU_INFO_FILE: return __FILE__;
		case CPU_INFO_CREDITS: return "Copyright (C) 1998,1999 Juergen Buchmueller, all rights reserved.";
	}
	return buffer[which];
}

unsigned z80_dasm( char *buffer, unsigned pc )
{
#ifdef MAME_DEBUG
    return DasmZ80( buffer, pc );
#else
	sprintf( buffer, "$%02X", cpu_readop(pc) );
	return 1;
#endif
}


